dnl
dnl  Sets CORBA support for omniORB v3 or higher.
dnl  $Id: mpcl-orb-omniorb.m4 8803 2004-02-02 00:12:49Z rafa $
dnl

dnl
dnl  Detects CPU architecture for OMNIORB. It defines these:
dnl
dnl    IA-32:         __x86__
dnl    Alpha:         __alpha__
dnl    Motorola 68x:  __m68k__
dnl    Sparc:         __sparc__
dnl    PowerPC:       __powerpc__
dnl
AC_DEFUN([MPCL_CHECK_ORB_OMNIORB_CPU],[
  AC_REQUIRE([AC_CANONICAL_TARGET])
  dnl
  dnl  Detects CPU architecture.
  dnl
  case "$host_cpu" in
    i*86)    AC_DEFINE(__x86__) ;;
    alpha)   AC_DEFINE(__alpha__) ;;
    m68k)    AC_DEFINE(__m68k__) ;;
    sparc)   AC_DEFINE(__sparc__) ;;
    powerpc) AC_DEFINE(__powerpc__) ;;
    *)       AC_MSG_ERROR("unknown CPU architecture") ;;
  esac
])

dnl
dnl  Detects Operating System for OMNIORB. It defines these:
dnl
dnl    IBM AIX:       __aix__
dnl    Digital Unix:  __osf1__
dnl    HPUX:          __hpux__
dnl    Linux:         __linux__
dnl    NextStep:      __nextstep__
dnl    Sun Solaris:   __sunos__
dnl
dnl    Operating System Version:  __OSVERSION__
dnl
AC_DEFUN([MPCL_CHECK_ORB_OMNIORB_OS],[
  AC_REQUIRE([AC_CANONICAL_TARGET])
  dnl
  dnl  Detects Operating System.
  dnl
  case "$host_os" in
    aix*)      AC_DEFINE(__aix__)      AC_DEFINE(__OSVERSION__, 4) ;;
    dgux*)     AC_DEFINE(__osf1__)     AC_DEFINE(__OSVERSION__, 3) ;;
    hpux*10*)  AC_DEFINE(__hpux__)     AC_DEFINE(__OSVERSION__, 10) ;;
    hpux*11*)  AC_DEFINE(__hpux__)     AC_DEFINE(__OSVERSION__, 11) ;;
    linux*)    AC_DEFINE(__linux__)    AC_DEFINE(__OSVERSION__, 2) ;;
    nextstep*) AC_DEFINE(__nextstep__) AC_DEFINE(__OSVERSION__, 3) ;;
    osf*)      AC_DEFINE(__osf1__)     AC_DEFINE(__OSVERSION__, 3) ;;
    solaris*)  AC_DEFINE(__sunos__)    AC_DEFINE(__OSVERSION__, 5) ;;
    *)         AC_MSG_ERROR("unknown Operating System environment") ;;
  esac
])

dnl
dnl  Defines variables needed for OMNIORB. It defines/updates these:
dnl
dnl    CORBA_H
dnl      Corba header.
dnl
dnl    CORBA_HAVE_POA
dnl      Defined if ORB has POA support.
dnl
dnl    CORBA_ORB_INIT_HAVE_3_ARGS
dnl      Defined if ORB init has three arguments.
dnl
dnl    CORBA_ORB_INIT_THIRD_ARG
dnl      Defines the third argument for init (if any).
dnl
dnl    COSNAMING_H
dnl      Corba COS naming service header.
dnl
dnl    HAVE_ORB_IDL
dnl      Defined if ORB has IDL.
dnl
dnl    IDL
dnl      IDL program name.
dnl
dnl    IDLFLAGS
dnl      IDL program flags.
dnl
dnl    IDLPOST
dnl      Program to run after IDL.
dnl
dnl    ORB
dnl      Name of the ORB used.
dnl
dnl    ORB_COSNAMING_LIB
dnl      Name of the COS naming library.
dnl
dnl    ORB_INCLUDES
dnl      INCLUDE addendum for ORB support.
dnl
dnl    ORB_LDADD
dnl      LDADD addendum for ORB support.
dnl
AC_DEFUN([MPCL_CHECK_ORB_OMNIORB],[
  AC_REQUIRE([AC_PROG_CC])
  AC_REQUIRE([AC_PROG_CXX])
  AC_REQUIRE([AC_PROG_CPP])
  AC_REQUIRE([AC_PROG_CXXCPP])
  AC_ARG_WITH(orb-omniORB,
    [  --with-orb-omniORB      support of ORB omniORB],
    OMNIORB=yes,
    OMNIORB=no
  )
  if test "x$OMNIORB" = "xyes"; then
    MPCL_CHECK_ORB_OMNIORB_CPU
    MPCL_CHECK_ORB_OMNIORB_OS
    AC_LANG_PUSH([C++])
    PREV_CXXCPPFLAGS=$CXXCPPFLAGS
    PREV_CPPFLAGS=$CPPFLAGS
    PREV_LIBS=$LIBS
    PREV_LDFLAGS=$LDFLAGS
    ORB_INCLUDES=
    ORB_LDADD=
    if test "x$OMNI_ROOT" != "x"; then
      ORB_INCLUDES="-I $OMNI_ROOT/include"
    fi
    CXXCPPFLAGS="$CXXCPPFLAGS $ORB_INCLUDES "
    CPPFLAGS="$CPPFLAGS $ORB_INCLUDES "
    AC_CHECK_HEADER(omniORB3/CORBA.h, [omni="yes" omni_version="3"], omni="no")
    AC_CHECK_HEADER(omniORB4/CORBA.h, [omni="yes" omni_version="4"], omni="no")
    if test "x$omni" = "xyes"; then
      LIBS="$LIBS -lomnithread -lpthread"
      AC_CACHE_CHECK([for CORBA ORB<omniORB> omnithreads],
        mpcl_cv_check_omnithreads,
        AC_TRY_LINK([#include <omnithread.h>],
          [omni_mutex my_mutex],
          mpcl_cv_check_omnithreads=yes,
          mpcl_cv_check_omnithreads=no
        )
      )

      dnl
      dnl  Checks for ORB omnithreads libs.
      dnl
      if test "x$mpcl_cv_check_omnithreads" = "xyes"; then
        ORB_LDADD="-lomnithread -lpthread"
      fi

      dnl
      dnl  Checks for ORB omniORB libs.
      dnl
      AC_CHECK_LIB(socket, socket,        LIBS="-lsocket $LIBS",,)
      AC_CHECK_LIB(nsl,    gethostbyname, LIBS="-lnsl $LIBS",,)
      if test "x$omni_version" = "x3"; then
        LIBS="-lomniORB${omni_version} -ltcpwrapGK $LIBS"
        ORB_LDADD="-lomniORB${omni_version} -ltcpwrapGK $ORB_LDADD"
      else
        LIBS="-lomniORB${omni_version} $LIBS"
        ORB_LDADD="-lomniORB${omni_version} $ORB_LDADD"
      fi
      AC_CACHE_CHECK([for CORBA ORB<omniORB>],
        mpcl_cv_check_omniORBlib,
        AC_TRY_LINK([#include <omniORB${omni_version}/CORBA.h>],
          [CORBA::ORB_var orb],
          mpcl_cv_check_omniORBlib=yes,
          mpcl_cv_check_omniORBlib=no
        )
      )
      if test ! "x$mpcl_cv_check_omniORBlib" = "xyes"; then
        dnl
        dnl  No support of ORB omniORB.
        dnl
        ORB=
      else
        dnl
        dnl  Full support of ORB omniORB.
        dnl
        CORBA_H="omniORB${omni_version}/CORBA.h"
        COSNAMING_H="omniORB${omni_version}/Naming.hh"
        HAVE_ORB_IDL=1
        IDL=omniidl
        IDLFLAGS="$IDLFLAGS -bcxx -Wbs=.cc"
        IDLPOST=true
        ORB=omniORB
        ORB_COSNAMING_LIB=
        AC_DEFINE(CORBA_HAVE_POA)
        AC_DEFINE(CORBA_ORB_INIT_HAVE_3_ARGS)
        AC_DEFINE(CORBA_ORB_INIT_THIRD_ARG, "omniORB${omni_version}")
        AC_DEFINE(OMNIORB)
        AC_DEFINE_UNQUOTED(CORBA_H,     <$CORBA_H>)
        AC_DEFINE_UNQUOTED(COSNAMING_H, <$COSNAMING_H>)
        AC_SUBST(HAVE_ORB_IDL)
        AC_SUBST(IDL)
        AC_SUBST(IDLFLAGS)
        AC_SUBST(IDLPOST)
        AC_SUBST(ORB)
        AC_SUBST(ORB_COSNAMING_LIB)
        AC_SUBST(ORB_INCLUDES)
        AC_SUBST(ORB_LDADD)
      fi

      if test "x$omni" = "xno"; then
        ORB=
      fi

      dnl
      dnl  Restores compiler/linker state.
      dnl
      CXXCPPFLAGS=$PREV_CXXCPPFLAGS
      CPPFLAGS=$PREV_CPPFLAGS
      LIBS=$PREV_LIBS
      LDFLAGS=$PREV_LDFLAGS
    fi
    AC_LANG_POP([C++])
  fi
])
