/*
*  Name:      exceptions.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   INVARIANT exceptions
*  Date:      $Date: 2004-08-02 19:20:39 +0200 (lun, 02 ago 2004) $
*  Revision:  $Revision: 9838 $
*
*  Copyright (C) 1994-2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_INVARIANT_EXCEPTIONS__
#define _MPCL_INVARIANT_EXCEPTIONS__

#include <iostream>
#include "../error_exception.hh"
#include "../exception.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for INVARIANT.
  namespace invariant
  {

    using std::basic_ostream;

    ///  Exception: parent exception class for INVARIANT.
    class TException : public virtual mpcl::TException {};

    ///  Exception: requirement violated.
    class TViolationException         :
      public virtual mpcl::TException ,
      public         TErrorException  ,
      public         TException
    {

      private:

        ///  Summary description.
        static const char*   _pkcSynopsis;

        ///  Violated conformance level.
        const int   iViolatedConformanceLevel;


      protected:

        //
        //  S E L E C T O R S
        //

        void write (basic_ostream<char>& rtTARGET_OSTREAM) const
        {
          if ( !fileName().empty() )
          {
            rtTARGET_OSTREAM << fileName() << ":" << lineNumber() << ":";
          }
          rtTARGET_OSTREAM << generalDescription() << iViolatedConformanceLevel << "; ";
          if ( !specificDescription().empty() )
          {
            rtTARGET_OSTREAM << specificDescription();
          }
          rtTARGET_OSTREAM << std::endl;
        }


      public:

        //
        //  C O N S T R U C T O R S
        //
        
        /**
        *  Builds the instance with a generic and a (if used) specific description
        *  of the exception.
        *  @param iVIOLATED_CONFORMANCE_LEVEL Violated conformance level.
        *  @param rkyRATIONALE                Specific description.
        *  @param rkyFILE_NAME                File name where the exception has thrown.
        *  @param kiLINE_NUMBER               Line number of the former file.
        */
        TViolationException ( int           iVIOLATED_CONFORMANCE_LEVEL ,
                              const string& rkyRATIONALE  = string()    ,
                              const string& rkyFILE_NAME  = string()    ,
                              const int     kiLINE_NUMBER = 0           )                     :
          mpcl::TException          (_pkcSynopsis, rkyRATIONALE, rkyFILE_NAME, kiLINE_NUMBER) ,
          TErrorException           ()                                                        ,
          TException                ()                                                        ,
          iViolatedConformanceLevel (iVIOLATED_CONFORMANCE_LEVEL)                             {}


      public:

        //
        //  S E L E C T O R S
        //

        int violatedConformanceLevel (void) const
        {
          return iViolatedConformanceLevel;
        }

    };  // class TViolationException
    
  }  // namespace invariant

}  // namespace mpcl


#endif  // not _MPCL_INVARIANT_EXCEPTIONS__
