/*
*  Name:      input_streamable.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Base input streamable class
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_IO_INPUT_STREAMABLE__
#define _MPCL_IO_INPUT_STREAMABLE__

#include <istream>


///  Name-space for MPCL.
namespace mpcl
{
  
  ///  Name-space for IO.
  namespace io
  {

    ///  Base input streamable class.
    template <typename TChar, typename TTraits>
    class IInputStreamable;

    /**
    *  Reads   the   instance   \a rtTARGET_INPUT_STREAMABLE   from   stream
    *  \a rtSOURCE_ISTREAM.
    */
    template <typename TChar, typename TTraits>
    std::basic_istream<TChar, TTraits>&
    operator >> ( std::basic_istream<TChar, TTraits>& rtSOURCE_ISTREAM          ,
                  IInputStreamable<TChar, TTraits>&   rtTARGET_INPUT_STREAMABLE );

    ///  Base input streamable class.
    template < typename TChar   = char                    ,
               typename TTraits = std::char_traits<TChar> >
    class IInputStreamable
    {

      public:

        ///  Character type.
        typedef
          TChar
          char_type;

        ///  Traits type.
        typedef
          TTraits
          traits_type;


      public:

        //
        //  C O N S T R U C T O R S
        //

        ///  Destroys the instance.
        virtual ~IInputStreamable (void) {}


      protected:

        //
        //  C O N S T R U C T O R S
        //

        /**
        *  Reads the instance from stream \a rtISTREAM.
        *  @param rtISTREAM Source input stream.
        */
        virtual void read (std::basic_istream<char_type, traits_type>& rtISTREAM) = 0;


      public:

        //
        //  F R I E N D   F U N C T I O N S
        //

        /**
        *  Reads the instance \a rtTARGET_INPUT_STREAMABLE
        *  from stream \a rtSOURCE_ISTREAM.
        */
        friend std::basic_istream<TChar, TTraits>&
        operator >> <TChar, TTraits>
        (
          std::basic_istream<TChar, TTraits>& rtSOURCE_ISTREAM          ,
          IInputStreamable<TChar, TTraits>&   rtTARGET_INPUT_STREAMABLE
        );

    };  // class IInputStreamable


    //
    //  F R I E N D   F U N C T I O N S
    //

    template <typename TChar, typename TTraits>
    std::basic_istream<TChar, TTraits>&
    operator >> ( std::basic_istream<TChar, TTraits>&   rtSOURCE_ISTREAM      ,
                  IInputStreamable<TChar, TTraits>& rtTARGET_INPUT_STREAMABLE )
    {
      rtTARGET_INPUT_STREAMABLE.read (rtSOURCE_ISTREAM);
      return rtSOURCE_ISTREAM;
    }

  }  // namespace io

}  // namespace mpcl


#endif  // not _MPCL_IO_INPUT_STREAMABLE__
