/*
*  Name:      output_streamable.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Base output streamable class
*  Date:      $Date: 2004-08-02 19:20:39 +0200 (lun, 02 ago 2004) $
*  Revision:  $Revision: 9838 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_IO_OUTPUT_STREAMABLE__
#define _MPCL_IO_OUTPUT_STREAMABLE__

#include <ostream>


///  Name-space for MPCL.
namespace mpcl
{
  
  ///  Name-space for IO.
  namespace io
  {

    ///  Forward declared class.
    template <typename TChar, typename TTraits>
    class IOutputStreamable;

    /**
    *  Writes the instance \a rktSOURCE_OUTPUT_STREAMABLE
    *  onto stream \a rtTARGET_STREAM.
    */
    template <typename TChar, typename TTraits>
    std::basic_ostream<TChar, TTraits>&
    operator << ( std::basic_ostream<TChar, TTraits>&      rtSOURCE_OSTREAM            ,
                  const IOutputStreamable<TChar, TTraits>& rktSOURCE_OUTPUT_STREAMABLE );

    ///  Base output streamable class.
    template < typename TChar   = char                    ,
               typename TTraits = std::char_traits<TChar> >
    class IOutputStreamable
    {

      public:

        ///  Character type.
        typedef
          TChar
          char_type;

        ///  Traits type.
        typedef
          TTraits
          traits_type;


      public:

        //
        //  C O N S T R U C T O R S
        //

        ///  Destroys the instance.
        virtual ~IOutputStreamable (void) {}


      protected:

        //
        //  S E L E C T O R S
        //

        /**
        *  Writes the instance onto stream \a rtTARGET_OSTREAM.
        *  @param rtTARGET_OSTREAM Target output stream.
        */
        virtual void write (std::basic_ostream<char_type, traits_type>& rtTARGET_OSTREAM) const = 0;


      public:

        //
        //  F R I E N D   F U N C T I O N S
        //

        friend std::basic_ostream<TChar, TTraits>&
        operator << <TChar, TTraits>
        (
          std::basic_ostream<TChar, TTraits>&      rtSOURCE_OSTREAM            ,
          const IOutputStreamable<TChar, TTraits>& rktSOURCE_OUTPUT_STREAMABLE
        );

    };  // class IOutputStreamable


    //
    //  F R I E N D   F U N C T I O N S
    //

    template <typename TChar, typename TTraits>
    std::basic_ostream<TChar, TTraits>&
    operator << ( std::basic_ostream<TChar, TTraits>&      rtSOURCE_OSTREAM            ,
                  const IOutputStreamable<TChar, TTraits>& rktSOURCE_OUTPUT_STREAMABLE )
    {
      rktSOURCE_OUTPUT_STREAMABLE.write (rtSOURCE_OSTREAM);
      return rtSOURCE_OSTREAM;
    }

  }  // namespace io

}  // namespace mpcl


#endif  // not _MPCL_OUTPUT_STREAMABLE__
