/*
*  Name:      client_application.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Client application
*  Date:      $Date: 2004-08-02 19:20:39 +0200 (lun, 02 ago 2004) $
*  Revision:  $Revision: 9838 $
*
*  Copyright (C) 2001-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_NET_CORBA_CLIENT_APPLICATION__
#define _MPCL_NET_CORBA_CLIENT_APPLICATION__

#include "../../abstract_application.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for NET.
  namespace net
  {

    ///  Name-space for CORBA.
    namespace corba
    {

      ///  Base class for client applications.
      template <typename TOrb>
      class TClientApplication : public TAbstractApplication
      {

        protected:

          ///  Client ORB.
          TOrb&   rtOrb;


        public:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Builds a new instance, initializes the ORB.
          *  @param pkcNAME    Application name.
          *  @param pkcRELEASE Application release.
          *  @param rtORB      The ORB object.
          */
          TClientApplication ( const char* pkcNAME    ,
                               const char* pkcRELEASE ,
                               TOrb&       rtORB      ) :
            TAbstractApplication (pkcNAME, pkcRELEASE)  ,
            rtOrb                (rtORB)                {}

          ///  Initializes application. It should register the client objects.
          void initialize (void) = 0;

          int start (void) = 0;

      };  // class TClientApplication

    }  // namespace corba

  }  // namespace net

}  // namespace mpcl


#endif  // not _MPCL_CLIENT_APPLICATION__
