/*
*  Name:      url_encoder.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   URL encoder class
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_NET_CGI_URL_ENCODER__
#define _MPCL_NET_CGI_URL_ENCODER__

#include "../text/string.hh"
#include "../util/collection/string_to_string_map.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for NET.
  namespace net
  {

    using text::TString;
    using util::collection::TStringToStringMap;

    ///  Class for encoding using content type 'application/x-www-form-urlencoded'.
    class TUrlEncoder
    {

      public:

        //
        //  S E L E C T O R S
        //

        /**
        *  Encodes a string using content type 'application/x-www-form-urlencoded'.
        *  @param rkySOURCE_PLAIN Plain string.
        *  @return Encoded string using content type 'application/x-www-form-urlencoded'.
        *  @see http://www.w3.org/TR/REC-html40/interact/forms.html#h-17.13.4.1
        */
        static TString _encode (const TString& rkySOURCE_PLAIN);

        /**
        *  Encodes a set of  control names and their values with the content type
        *  'application/x-www-form-urlencoded'  and  returns  a  string  with the
        *  result.
        *  @param rktSOURCE_PARAMETER_MAP Map with pairs of control name, value.
        *  @param gEMPTY_PARAMETERS_TOO   If true the empty parameters will be encoded.
        *  @return A string encoded using content type 'application/x-www-form-urlencoded'
        *          with all control names and values.
        *  @see http://www.w3.org/TR/REC-html40/interact/forms.html#h-17.13.4.1
        */
        static TString _encode ( const TStringToStringMap& rktSOURCE_PARAMETER_MAP      ,
                                 bool                      gEMPTY_PARAMETERS_TOO = true );

    };  // class TUrlEncoder

  }  // namespace net

}  // namespace mpcl


#endif  // not _MPCL_NET_CGI_URL_ENCODER__
