/*
*  Name:      mutex.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Base mutex
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1999-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_SYSTEM_MUTEX__
#define _MPCL_SYSTEM_MUTEX__


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for SYSTEM.
  namespace system
  {

    /**
    *  Mutex base class.
    *
    *  A mutex is a MUTual EXclusion device, and is useful for protecting shared
    *  data structures from concurrent modifications, and implementing critical
    *  sections and monitors.
    *
    *  A mutex has two possible states: unlocked (not owned by any thread), and
    *  locked (owned by one thread). A mutex can never be owned by two different
    *  threads simultaneously. A thread attempting to lock a mutex that is already
    *  locked by another thread is suspended until the owning thread unlocks the
    *  mutex first.
    *
    *  @see TBaseOperatingSystem.
    */
    class IMutex
    {

      public:

        //
        //  C O N S T R U C T O R S
        //

        ///  Destroys the instance.
        virtual ~IMutex (void) {}

        ///  Lock mutex.
        virtual void lock (void) = 0;

        ///  Unlock mutex.
        virtual void unlock (void) = 0;

        /**
        *  Lock mutex if unlocked, if not, then it returns false.
        *  @return True if unlocked (locking it, if so).
        */
        virtual bool tryLock (void) = 0;

    };  // class IMutex

  }  // namespace system

}  // namespace mpcl


#endif  // not _MPCL_SYSTEM_MUTEX__
