/*
*  Name:      clause_body_string.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Clause-body string
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_CODEGEN_CLAUSE_BODY_STRING__
#define _MPCL_TEXT_CODEGEN_CLAUSE_BODY_STRING__

#include "../../io/streamable.hh"
#include "../../util/collection/string_to_string_map.hh"
#include "../string.hh"
#include "defs.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for CODEGEN.
    namespace codegen
    {

      using io::IStreamable;
      using std::basic_istream;
      using std::basic_ostream;
      using util::collection::TStringToStringMap;

      ///  Forwarded declaration.
      class TClauseBodyString;

      /**
      *  Reads the instance \a ryTARGET_CLAUSE_BODY from stream \a rtSOURCE_ISTREAM.
      *  This operator is needed cause father operators.
      */
      template <typename TChar, typename TTraits>
      basic_istream<TChar, TTraits>&
      operator >> ( basic_istream<TChar, TTraits>& rtSOURCE_ISTREAM     ,
                    TClauseBodyString&             ryTARGET_CLAUSE_BODY );

      /**
      *  Writes the instance \a rkySOURCE_CLAUSE_BODY onto stream \a rtTARGET_STREAM.
      *  This operator is needed cause father operators.
      */
      template <typename TChar, typename TTraits>
      basic_ostream<TChar, TTraits>&
      operator << ( basic_ostream<TChar, TTraits>& rtSOURCE_OSTREAM      ,
                    const TClauseBodyString&       rkySOURCE_CLAUSE_BODY );

      /**
      *  Clause body string for pattern based code generator.
      *  @see TPatternBasedCodeGenerator.
      */
      class TClauseBodyString :
        public TString        ,
        public IStreamable<>
      {

        public:

          ///  Disambiguate char type.
          typedef
            IStreamable<>::char_type
            char_type;

          ///  Disambiguate traits type.
          typedef
            IStreamable<>::traits_type
            traits_type;


        protected:

          /**
          *  Boolean with parameter existence sensitiveness when the
          *  instantiation has to be done.
          */
          bool   gParameterExistenceSensitiveness;


        public:

          //
          //  C O N S T R U C T O R S
          //

          ///  Builds a new instance.
          TClauseBodyString (void)                  :
            TString                          ()     ,
            IStreamable<>                    ()     ,
            gParameterExistenceSensitiveness (true) {}

          /**
          *  Builds a new instance from string \a pkcSOURCE_CLAUSE_BODY.
          *  @param pkcSOURCE_CLAUSE_BODY Source string.
          */
          TClauseBodyString (const char* pkcSOURCE_CLAUSE_BODY)      :
            TString                          (pkcSOURCE_CLAUSE_BODY) ,
            IStreamable<>                    ()                      ,
            gParameterExistenceSensitiveness (true)                  {}

          /**
          *  Builds a new instance from string \a rkySOURCE_CLAUSE_BODY.
          *  @param rkySOURCE_CLAUSE_BODY Source string.
          */
          TClauseBodyString (const TString& rkySOURCE_CLAUSE_BODY)   :
            TString                          (rkySOURCE_CLAUSE_BODY) ,
            IStreamable<>                    ()                      ,
            gParameterExistenceSensitiveness (true)                  {}

          /**
          *  Copies from instance \a rkySOURCE_CLAUSE_BODY.
          *  @param rkySOURCE_CLAUSE_BODY Source instance.
          *  @return This instance.
          */
          TClauseBodyString& operator = (const TClauseBodyString& rkySOURCE_CLAUSE_BODY);

          /**
          *  Sets the attribute-existence sensitiveness.
          *  @param gSENSITIVENESS Sensitiveness state.
          */
          void setParameterExistenceSensitiveness (bool gSENSITIVENESS)
          {
            gParameterExistenceSensitiveness = gSENSITIVENESS;
          }


        protected:

          //
          //  C O N S T R U C T O R S
          //

          ///  Reads the instance from stream \a rtSOURCE_ISTREAM.
          void read (basic_istream<char_type, traits_type>& rtSOURCE_ISTREAM);


        public:

          //
          //  S E L E C T O R S
          //

          /**
          *  Gets a string that is a instance of the code pattern.
          *  @return Instantiated string.
          */
          TString instantiate (void) const
          {
            return preprocess();
          }

          /**
          *  Gets a string that is a instance of the code pattern result of
          *  substituting \a pkcFIRST_PARAMETER_NAME by \a pkcFIRST_PARAMETER_VALUE,
          *  and so, with the rest of optional parameters pairs.
          *  @param pkcFIRST_PARAMETER_NAME  First parameter name.
          *  @param pkcFIRST_PARAMETER_VALUE First parameter value.
          *  @param ...                      Next parameter name/value pairs.
          *  @return Instantiated string.
          */
          TString instantiate ( const char* pkcFIRST_PARAMETER_NAME     ,
                                const char* pkcFIRST_PARAMETER_VALUE... ) const;

          /**
          *  Gets a string that is a instance of the code pattern result of
          *  substituting variables in \a rktSOURCE_VARIABLE_MAP.
          *  @param rktSOURCE_VARIABLE_MAP  Source variable map.
          *  @return Instantiated string.
          *  @see TStringToVariableMap.
          */
          TString instantiate (const TStringToVariableMap& rktSOURCE_VARIABLE_MAP) const
          {
            return instantiate (rktSOURCE_VARIABLE_MAP, gParameterExistenceSensitiveness);
          }

          /**
          *  Gets a string that is a instance of the code pattern result of
          *  substituting variables in \a rktSOURCE_STRING_TO_STRING_MAP.
          *  @param rktSOURCE_STRING_TO_STRING_MAP  Source variable map.
          *  @return Instantiated string.
          *  @see TStringToStringMap.
          */
          TString instantiate (const TStringToStringMap& rktSOURCE_STRING_TO_STRING_MAP) const
          {
            return instantiate (rktSOURCE_STRING_TO_STRING_MAP, gParameterExistenceSensitiveness);
          }

          /**
          *  Gets a string that is a instance of the code pattern result of
          *  substituting variables in \a rktSOURCE_VARIABLE_MAP. If
          *  \a gPARAMETER_EXISTENCE_SENSITIVENESS is true, then any variable that
          *  doesn't exist in this instance string will cause an exception throw.
          *  @param rktSOURCE_VARIABLE_MAP             Source variable map.
          *  @param gPARAMETER_EXISTENCE_SENSITIVENESS True if there musts generate an
          *                                            exception if a  variable is not
          *                                            in this instance string.
          *  @return Instantiated string.
          *  @see TStringToVariableMap.
          */
          TString
          instantiate ( const TStringToVariableMap& rktSOURCE_VARIABLE_MAP             ,
                        bool                        gPARAMETER_EXISTENCE_SENSITIVENESS ) const;

          /**
          *  Gets a string that is a instance of the code pattern result of
          *  substituting variables in \a rktSOURCE_STRING_MAP. If
          *  \a gPARAMETER_EXISTENCE_SENSITIVENESS is true, then any variable that
          *  doesn't exist in this instance string will cause an exception throw.
          *  @param rktSOURCE_STRING_MAP               Source variable map.
          *  @param gPARAMETER_EXISTENCE_SENSITIVENESS True if there musts generate an
          *                                            exception if a  variable is not
          *                                            in this instance string.
          *  @return Instantiated string.
          *  @see TStringToStringMap.
          */
          TString
          instantiate ( const TStringToStringMap& rktSOURCE_STRING_MAP               ,
                        bool                      gPARAMETER_EXISTENCE_SENSITIVENESS ) const;


        protected:

          //
          //  S E L E C T O R S
          //

          /**
          *  Writes the instance onto stream \a rtTARGET_OSTREAM.
          *  @param rtTARGET_OSTREAM Target stream.
          */
          void write (basic_ostream<char_type, traits_type>& rtTARGET_OSTREAM) const;

          /**
          *  Gets a string that is the result of preprocessing current code
          *  (changing entities for its values).
          *  @return Pre-processed string.
          */
          TString preprocess (void) const;


        public:

          //
          //  F R I E N D   F U N C T I O N S
          //

          friend basic_istream<value_type, traits_type>&
          operator >> <value_type, traits_type>
          (
            basic_istream<value_type, traits_type>& rtSOURCE_ISTREAM     ,
            TClauseBodyString&                      ryTARGET_CLAUSE_BODY
          );

          friend basic_ostream<value_type, traits_type>&
          operator << <value_type, traits_type>
          (
            basic_ostream<value_type, traits_type>& rtSOURCE_OSTREAM      ,
            const TClauseBodyString&                rkySOURCE_CLAUSE_BODY
          );

      };  // class TClauseBodyString

      //
      //  F R I E N D   F U N C T I O N S
      //

      template <typename TChar, typename TTraits>
      basic_istream<TChar, TTraits>&
      operator >> ( basic_istream<TChar, TTraits>& rtSOURCE_ISTREAM     ,
                    TClauseBodyString&             ryTARGET_CLAUSE_BODY )
      {
        ryTARGET_CLAUSE_BODY.read (rtSOURCE_ISTREAM);
        return rtSOURCE_ISTREAM;
      }

      template <typename TChar, typename TTraits>
      basic_ostream<TChar, TTraits>&
      operator << ( basic_ostream<TChar, TTraits>& rtSOURCE_OSTREAM      ,
                    const TClauseBodyString&       rkySOURCE_CLAUSE_BODY )
      {
        rkySOURCE_CLAUSE_BODY.write (rtSOURCE_OSTREAM);
        return rtSOURCE_OSTREAM;
      }

    }  // namespace codegen

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_CODEGEN_CLAUSE_BODY_STRING__
