/*
*  Name:      defs.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   CODEGEN definitions
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_CODEGEN_DEFS__
#define _MPCL_TEXT_CODEGEN_DEFS__

#include "../../util/collection/map.hh"
#include "../string.hh"
#include "defs.hh"
#include "exceptions.hh"
#include "variable_string.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for CODEGEN.
    namespace codegen
    {

      using util::collection::TMap;

      ///  Variable map.
      typedef TMap<TString, TVariableString>   TStringToVariableMap;


      //
      //  E X P O R T E D   V A R I A B L E S
      //

      //
      //  Tag declarations.
      //
      extern const char*   pkcCommentTagPattern;
      extern const char*   pkcDOCTYPE_TagPattern_1;
      extern const char*   pkcDOCTYPE_TagPattern_2;
      extern const char*   pkcDOCTYPE_TagPattern_3;
      extern const char*   pkcDOCTYPE_TagPattern_4;
      extern const char*   pkcCDML_TagPattern_1;
      extern const char*   pkcCDML_TagPattern_2;
      extern const char*   pkcCDML_TagPattern_3;
      extern const char*   pkcCDML_EndTagPattern;
      extern const char*   pkcDESC_ElementPattern;
      extern const char*   pkcDECLARE_TagPattern;
      extern const char*   pkcDECLARE_EndTagPattern;
      extern const char*   pkcINSTRUCT_TagPattern;
      extern const char*   pkcINSTRUCT_EndTagPattern;
      extern const char*   pkcVARIABLE_ElementPattern_1;
      extern const char*   pkcVARIABLE_ElementPattern_2;
      extern const char*   pkcVARIABLE_ElementPattern_3;
      extern const char*   pkcCLAUSE_TagBegin;
      extern const char*   pkcCLAUSE_TagNameAttr;
      extern const char*   pkcCLAUSE_TagTargetAttr;
      extern const char*   pkcCLAUSE_TagNoCheckAttr;
      extern const char*   pkcCLAUSE_TagEnd;
      extern const char*   pkcCLAUSE_BodyPattern;

      //
      //  Entity declarations.
      //
      extern const char*   pkcLT_EntityPattern;
      extern const char*   pkcLT_EntityValue;
      extern const char*   pkcGT_EntityPattern;
      extern const char*   pkcGT_EntityValue;
      extern const char*   pkcNL_EntityPattern;
      extern const char*   pkcNL_EntityValue;
      extern const char*   pkcEOC_EntityPattern;
      extern const char*   pkcEntityPrefix;
      extern const char*   pkcAMP_EntityPattern;
      extern const char*   pkcAMP_EntityValue;

      //
      //  Entity lengths declarations.
      //
      extern size_t   zEntityPrefixLength;
      extern size_t   zLT_EntityPatternLength;
      extern size_t   zGT_EntityPatternLength;
      extern size_t   zNL_EntityPatternLength;
      extern size_t   zEOC_EntityPatternLength;
      extern size_t   zLT_EntityValueLength;
      extern size_t   zGT_EntityValueLength;
      extern size_t   zNL_EntityValueLength;
      extern size_t   zAMP_EntityPatternLength;
      extern size_t   zAMP_EntityValueLength;

      //
      //  This is the separator used when encoding (name-mangling)
      //  clauses with an associated target.
      //
      extern const char*   pkcTargetSeparator;

      //
      //  E X P O R T E D   F U N C T I O N S
      //

      ///  Operating system instance.
      extern void InstantiateEntities (TString& ryTARGET_STRING);

    }  // namespace codegen

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_CODEGEN_DEFS__
