/*
*  Name:      instruction_tag_string.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Instruction-tag string
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_CODEGEN_INSTRUCTION_TAG_STRING__
#define _MPCL_TEXT_CODEGEN_INSTRUCTION_TAG_STRING__

#include "../../io/streamable.hh"
#include "../regex/matcher.hh"
#include "../string.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for CODEGEN.
    namespace codegen
    {

      using io::IStreamable;
      using std::basic_istream;
      using std::basic_ostream;

      ///  Forwarded declaration.
      class TInstructionTagString;

      /**
      *  Reads    the    instance    \a  ryTARGET_INSTRUCTION_TAG    from    stream
      *  \a rtSOURCE_ISTREAM. This operator is needed cause father operators.
      */
      template <typename TChar, typename TTraits>
      basic_istream<TChar, TTraits>&
      operator >> ( basic_istream<TChar, TTraits>& rtSOURCE_ISTREAM         ,
                    TInstructionTagString&         ryTARGET_INSTRUCTION_TAG );

      /**
      *  Writes the instance \a rkySOURCE_INSTRUCTION_TAG onto stream \a rtTARGET_STREAM.
      *  This operator is needed cause father operators.
      */
      template <typename TChar, typename TTraits>
      basic_ostream<TChar, TTraits>&
      operator << ( basic_ostream<TChar, TTraits>& rtSOURCE_OSTREAM          ,
                    const TInstructionTagString&   rkySOURCE_INSTRUCTION_TAG );

      /**
      *  Instruction tag string for pattern based code generator.
      *  @see TPatternBasedCodeGenerator.
      */
      class TInstructionTagString :
        public TString            ,
        public IStreamable<>
      {

        public:

          ///  Character type.
          typedef
            IStreamable<>::char_type
            char_type;

          ///  Traits type.
          typedef
            IStreamable<>::traits_type
            traits_type;


        public:

          //
          //  C O N S T R U C T O R S
          //

          ///  Builds a new instance.
          TInstructionTagString (void) :
            TString       ()           ,
            IStreamable<> ()           {}

          /**
          *  Builds a new instance from text \a pkcSOURCE_TEXT.
          *  @param pkcSOURCE_TEXT Source text.
          */
          TInstructionTagString (const char* pkcSOURCE_TEXT) :
            TString       (pkcSOURCE_TEXT)                   ,
            IStreamable<> ()                                 {}

          /**
          *  Builds a new instance from instance \a rkySOURCE_INSTRUCTION_TAG.
          *  @param rkySOURCE_INSTRUCTION_TAG Source instance.
          */
          TInstructionTagString (const TInstructionTagString& rkySOURCE_INSTRUCTION_TAG) :
            TString       (rkySOURCE_INSTRUCTION_TAG)                                    ,
            IStreamable<> ()                                                             {}


        protected:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Reads instance from stream \a rsSOURCE_ISTREAM.
          *  @param rtSOURCE_ISTREAM Source stream.
          */
          void read (basic_istream<char_type, traits_type>& rtSOURCE_ISTREAM);


        protected:

          //
          //  S E L E C T O R S
          //

          ///  Writes instance onto stream \a rsTARGET_OSTREAM.
          void write (basic_ostream<char_type, traits_type>& rtTARGET_OSTREAM) const;


        public:

          //
          //  F R I E N D   F U N C T I O N S
          //

          friend basic_istream<value_type, traits_type>&
          operator >> <value_type, traits_type>
          (
            basic_istream<value_type, traits_type>& rtSOURCE_ISTREAM         ,
            TInstructionTagString&                  ryTARGET_INSTRUCTION_TAG
          );

          friend basic_ostream<value_type, traits_type>&
          operator << <value_type, traits_type>
          (
            basic_ostream<value_type, traits_type>& rtSOURCE_OSTREAM          ,
            const TInstructionTagString&            rkySOURCE_INSTRUCTION_TAG
          );

      };  // class TInstructionTagString

      //
      //  F R I E N D   F U N C T I O N S
      //

      template <typename TChar, typename TTraits>
      basic_istream<TChar, TTraits>&
      operator >> ( basic_istream<TChar, TTraits>& rtSOURCE_ISTREAM         ,
                    TInstructionTagString&         ryTARGET_INSTRUCTION_TAG )
      {
        ryTARGET_INSTRUCTION_TAG.read (rtSOURCE_ISTREAM);
        return rtSOURCE_ISTREAM;
      }

      template <typename TChar, typename TTraits>
      basic_ostream<TChar, TTraits>&
      operator << ( basic_ostream<TChar, TTraits>& rtSOURCE_OSTREAM          ,
                    const TInstructionTagString&   rkySOURCE_INSTRUCTION_TAG )
      {
        rkySOURCE_INSTRUCTION_TAG.write (rtSOURCE_OSTREAM);
        return rtSOURCE_OSTREAM;
      }

    }  // namespace codegen

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_CODEGEN_INSTRUCTION_TAG_STRING__
