/*
*  Name:      form.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   HTML form
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_HTML_FORM__
#define _MPCL_TEXT_HTML_FORM__

#include <vector>
#include "container.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for HTML.
    namespace html
    {

      ///  Forward declaration.
      class TForm;

      ///  Smart pointer to TForm.
      typedef
        TSmartPointer<TForm>
        QTForm;

      ///  Smart pointer to const TForm.
      typedef
        TSmartPointer<const TForm>
        QKTForm;

      ///  HTML form.
      class TForm : public TContainer
      {

        public:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Builds a new instance.
          *  @param pkcIDENTIFIER          Tag identifier.
          *  @param pkcCGI_PATH            CGI full path.
          *  @param pkcCGI_METHOD          CGI method for sending data.
          *  @param pkcTARGET              Target frame name (if any).
          *  @param pkcTARGET_NAMED_ANCHOR Target anchor.
          */
          TForm ( const char* pkcIDENTIFIER                   ,
                  const char* pkcCGI_PATH                     ,
                  const char* pkcCGI_METHOD          = "post" ,
                  const char* pkcTARGET              = ""     ,
                  const char* pkcTARGET_NAMED_ANCHOR = ""     ) :
            TContainer (pkcIDENTIFIER, pkcCGI_PATH)
          {
            tAttributeMap ["class-identifier"] = "form";
            tAttributeMap.bind ("cgi-path",            pkcCGI_PATH);
            tAttributeMap.bind ("cgi-method",          pkcCGI_METHOD);
            tAttributeMap.bind ("target",              pkcTARGET);
            tAttributeMap.bind ("target-named-anchor", pkcTARGET_NAMED_ANCHOR);
            gIsRootNode        = true;
            gIsQualified       = true;
            gForwardIdentifier = false;
          }

          /**
          *  Sets values (in \a rktVALUE_ARRAY)  for object named \a rkyIDENTIFIER.
          *  @param rkyIDENTIFIER  Object identifier.
          *  @param rktVALUE_ARRAY Source value array.
          */
          void setValues ( const TString&              rkyIDENTIFIER  ,
                           const std::vector<TString>& rktVALUE_ARRAY )
          {
            using std::vector;

            vector<TString>::const_iterator   I     = rktVALUE_ARRAY.begin();
            vector<TString>::const_iterator   ktEnd = rktVALUE_ARRAY.end();
            QTTag                             qtTag = findOrInsertTag (rkyIDENTIFIER);

            for (; ( I != ktEnd ) ;++I)
            {
              qtTag->setValue (*I);
            }
          }

      };  // class TForm

    }  // namespace html

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_HTML_FORM__
