/*
*  Name:      frame.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   HTML frame
*  Date:      $Date: 2004-08-02 19:20:39 +0200 (lun, 02 ago 2004) $
*  Revision:  $Revision: 9838 $
*
*  Copyright (C) 1994-2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_HTML_FRAME__
#define _MPCL_TEXT_HTML_FRAME__

#include "tag.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for HTML.
    namespace html
    {

      ///  Forward declaration.
      class TFrame;

      ///  Smart pointer to TFrame.
      typedef
        TSmartPointer<TFrame>
        QTFrame;

      ///  Smart pointer to const TFrame.
      typedef
        TSmartPointer<const TFrame>
        QKTFrame;

      ///  HTML frame.
      class TFrame : public TTag
      {

        public:

          //
          //  C O N S T R U C T O R S
          //

          TFrame ( const char* pkcIDENTIFIER         ,
                   const char* pkcSRC                ,
                   const char* pkcMARGINWIDTH        ,
                   const char* pkcMARGINHEIGHT       ,
                   bool        gNORESIZE             ,
                   const char* pkcSCROLLING = "auto" ) :
            TTag (pkcIDENTIFIER)
          {
            tAttributeMap ["class-identifier"] = "frame";
            tAttributeMap.bind ("frameborder",  "1");
            tAttributeMap.bind ("marginwidth",  pkcMARGINWIDTH);
            tAttributeMap.bind ("marginheight", pkcMARGINHEIGHT);
            tAttributeMap.bind ("noresize",     BoolToString (gNORESIZE));
            tAttributeMap.bind ("scrolling",    pkcSCROLLING);
            tAttributeMap.bind ("src",          pkcSRC);
          }

      };  // class TFrame

    }  // namespace html

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_HTML_FRAME__
