/*
*  Name:      framed_page.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   HTML framed page
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_HTML_FRAMED_PAGE__
#define _MPCL_TEXT_HTML_FRAMED_PAGE__

#include "base_page.hh"
#include "frameset.hh"
#include "head.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for HTML.
    namespace html
    {

      ///  Forward declaration.
      class TFramedPage;

      ///  Smart pointer to TFramedPage.
      typedef
        TSmartPointer<TFramedPage>
        QTFramedPage;

      ///  Smart pointer to const TFramedPage.
      typedef
        TSmartPointer<const TFramedPage>
        QKTFramedPage;

      ///  Framed page.
      class TFramedPage : public TBaseHtmlPage
      {

        protected:

          ///  Frameset of the page.
          QTFrameset   qtFrameset;

          ///  Head of the page.
          QTHead   qtHead;


        public:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Builds a new instance. It also inserts a head and a frameset.
          *  @param pkcIDENTIFIER Tag identifier.
          */
          TFramedPage (const char* pkcIDENTIFIER)               :
            TBasePage  (pkcIDENTIFIER)                          ,
            qtFrameset (new TFrameset ("100%", "50%,50%", "0")) ,
            qtHead     (new THead())
          {
            tAttributeMap ["class-identifier"] = "framed-page";
            insert (QTTag (qtHead));
            insert (QTTag (qtFrameset));
          }

          /**
          *  Builds a new instance and inserts a head and a frameset.  Also inserts
          *  a title (\a pkcTITLE) into the head.
          *  @param pkcIDENTIFIER Tag identifier.
          *  @param pkcTITLE      Title of the page.
          */
          TFramedPage (const char* pkcIDENTIFIER, const char* pkcTITLE) :
            TBasePage  (pkcIDENTIFIER)                                  ,
            qtFrameset (new TFrameset ("100%", "50%,50%", "0"))         ,
            qtHead     (new THead())
          {
            tAttributeMap ["class-identifier"] = "framed-page";
            insert (QTTag (qtHead));
            insert (QTTag (qtFrameset));
            qtHead->insert (QTTag (new TTitle (pkcTITLE)));
          }

      };  // class TFramedPage

    }  // namespace html

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_HTML_FRAMED_PAGE__
