/*
*  Name:      input_image.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   HTML input image
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_HTML_INPUT_IMAGE__
#define _MPCL_TEXT_HTML_INPUT_IMAGE__

#include "tag.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for HTML.
    namespace html
    {

      /**
      *  HTML input image.
      *
      *  Attributes added:
      *
      *    "qualified-identifier" ::= attribute ("identifier") +
      *                               kcIdentifierSeparator    +
      *                               attribute ("value")
      */
      class TInputImage : public TTag
      {

        public:

          //
          //  C O N S T R U C T O R S
          //

          ///  Builds a new instance.
          TInputImage ( const char* pkcIDENTIFIER        ,
                        const char* pkcSRC               ,
                        const char* pkcVALUE  = ""       ,
                        const char* pkcALIGN  = "middle" ,
                        const char* pkcBORDER = "0"      ) :
            TTag (pkcIDENTIFIER, pkcVALUE)
          {
            gIsQualified                           = true;
            tAttributeMap ["class-identifier"]     = "input-image";
            tAttributeMap ["qualified-identifier"] =
              tAttributeMap ["identifier"] +
              kcIdentifierValueSeparator   +
              tAttributeMap ["value"]      ;
            tAttributeMap.bind ("src",    pkcSRC);
            tAttributeMap.bind ("align",  pkcALIGN);
            tAttributeMap.bind ("border", pkcBORDER);
          }

      };  // class TInputImage

    }  // namespace html

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_HTML_INPUT_IMAGE__
