/*
*  Name:      link.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   HTML link
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 2000-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_HTML_LINK__
#define _MPCL_TEXT_HTML_LINK__

#include "tag.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for HTML.
    namespace html
    {

      ///  Forward declaration.
      class TLink;

      ///  Smart pointer to TLink.
      typedef
        TSmartPointer<TLink>
        QTLink;

      ///  Smart pointer to const TLink.
      typedef
        TSmartPointer<const TLink>
        QKTLink;

      ///  HTML link.
      class TLink : public TTag
      {

        public:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Builds a new instance.
          *  @param pkcTITLE Title of the link.
          *  @param pkcHREF  Attribute HREF of the link.
          *  @param pkcREL   Attribute REL of the link.
          *  @param pkcTYPE  Attribute TYPE of the link.
          *  @see html::pkcTypeTextCss.
          */
          TLink ( const char* pkcTITLE ,
                  const char* pkcHREF  ,
                  const char* pkcREL   ,
                  const char* pkcTYPE  ) :
            TTag (pkcTITLE)
          {
            tAttributeMap ["class-identifier"] = "link";
            tAttributeMap.bind ("href", pkcHREF);
            tAttributeMap.bind ("rel",  pkcREL);
            tAttributeMap.bind ("type", pkcTYPE);
          }

      };  // class TLink

    }  // namespace html

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_HTML_LINK__
