/*
*  Name:      pattern_page.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   HTML pattern page
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_HTML_PATTERN_PAGE__
#define _MPCL_TEXT_HTML_PATTERN_PAGE__

#include <iostream>
#include <string>
#include "../../io/input_streamable.hh"
#include "base_page.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for HTML.
    namespace html
    {

      using io::IInputStreamable;

      /**
      *  HTML pattern page. This page is loaded from an input file. The name of the
      *  tags  contained  in  the  page  must  appear  in the  input  file  between
      *  percentage symbols. If you want to escape a percentage symbol, use '%%'.
      */
      class TPatternPage             :
        public    TBasePage          ,
        protected IInputStreamable<>
      {

        private:

          ///  Filename of the file with the HTML pattern page.
          TString   yFileName;

          ///  Pattern of this HTML page.
          TString   yPattern;


        protected:

          //
          //  C O N S T R U C T O R S
          //

          void read (std::basic_istream<char>& rtSOURCE_ISTREAM);


        public:

          //
          //  C O N S T R U C T O R S
          //

          TPatternPage (const char* pkcIDENTIFIER, const char* pkcFILE_NAME) :
            TBasePage (pkcIDENTIFIER)                                        ,
            yFileName (pkcFILE_NAME)                                         ,
            yPattern  ()
          {
            tAttributeMap ["class-identifier"] = "page";
            readFromFile (yFileName);
          }

          TPatternPage (const char* pkcIDENTIFIER, const TString& rkyFILE_NAME) :
            TBasePage (pkcIDENTIFIER)                                           ,
            yFileName (rkyFILE_NAME)                                            ,
            yPattern  ()
          {
            tAttributeMap ["class-identifier"] = "page";
            readFromFile (yFileName);
          }

          /**
          *  Builds a new instance.  This instance is not completely  built because
          *  it has not the file name of the pattern data to be loaded.
          *  @param pkcIDENTIFIER Page identifier.
          */
          TPatternPage (const char* pkcIDENTIFIER) :
            TBasePage (pkcIDENTIFIER)              ,
            yFileName ()                           ,
            yPattern  ()
          {
            tAttributeMap ["class-identifier"] = "page";
          }

          void readFromFile (const TString& rkyFILE_NAME);


        protected:

          //
          //  S E L E C T O R S
          //

          void writeUsing ( std::basic_ostream<char>& rtTARGET_OSTREAM               ,
                            const TString&            rkySOURCE_QUALIFIED_IDENTIFIER ) const;

      };  // class TPatternPage

    }  // namespace html

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_HTML_PATTERN_PAGE__
