/*
*  Name:      table.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   HTML table
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_HTML_TABLE__
#define _MPCL_TEXT_HTML_TABLE__

#include "container.hh"
#include "table_row.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for HTML.
    namespace html
    {

      ///  Forward declaration.
      class TTable;

      ///  Smart pointer to TTable.
      typedef
        TSmartPointer<TTable>
        QTTable;

      ///  Smart pointer to const TTable.
      typedef
        TSmartPointer<const TTable>
        QKTTable;

      /**
      *  HTML table.
      *
      *  This container behaves as a normal container,  so if you want to access a
      *  row, this row has  to be identified by a  canonical identifier across all
      *  rows.
      */
      class TTable : public TContainer
      {

        public:

          //
          //  C O N S T R U C T O R S
          //

          TTable ( const char* pkcIDENTIFIER         ,
                   const char* pkcCAPTION = ""       ,
                   const char* pkcALIGN   = "center" );

          /**
          *  Tries to  find a row named  \a rkyIDENTIFIER  from the rows stored (if
          *  any)  in  this  instance.  If  the  tag  is  not  found,  then  a  new
          *  \a TTableRow (named as \a rkyIDENTIFIER) is inserted.
          *  @param rkyIDENTIFIER Source tag identifier.
          *  @return Returns that row.
          */
          QTTag findOrInsertTag (const TString& rkyIDENTIFIER);

      };  // class TTable

    }  // namespace html

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_HTML_TABLE__
