/*
*  Name:      table_cell.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   HTML table cell
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_HTML_TABLE_CELL__
#define _MPCL_TEXT_HTML_TABLE_CELL__

#include "container.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for HTML.
    namespace html
    {

      ///  Forward declaration for friend class.
      class TTable;

      ///  Forward declaration for friend class.
      class TLayoutTable;

      ///  Forward declaration.
      class TTableCell;

      ///  Smart pointer to TTableCell.
      typedef
        TSmartPointer<TTableCell>
        QTTableCell;

      ///  Smart pointer to const TTableCell.
      typedef
        TSmartPointer<const TTableCell>
        QKTTableCell;

      /**
      *  HTML table cell.  This tag is a  HTML table cell  that can be a TD or a TH
      *  element.
      *
      *  \warning In  order  of  been useful when it is loaded from form  data,  it
      *           supplants  the  tag that is  been contained (overloading  methods
      *           identifier(), value() and operator()()).
      */
      class TTableCell : public TContainer
      {

          //
          //  F R I E N D   C L A S S E S
          //

          friend class TTable;
          friend class TLayoutTable;


        public:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Builds a new instance.
          *  @param rkqtSOURCE_TAG Source tag to insert in table cell.
          *  @param pkcTYPE        One of these values: "data" and "header".
          *  @param pkcALIGN       HTML align attribute.
          *  @param pkcVALIGN      HTML valign attribute.
          */
          TTableCell ( const QTTag& rkqtSOURCE_TAG       ,
                       const char*  pkcTYPE   = "data"   ,
                       const char*  pkcALIGN  = "center" ,
                       const char*  pkcVALIGN = "middle" );

          /**
          *  Builds a new instance.
          *  @param pkcTYPE   One of these values: "data" and "header".
          *  @param pkcALIGN  HTML align attribute.
          *  @param pkcVALIGN HTML valign attribute.
          */
          TTableCell ( const char* pkcTYPE   = "data"   ,
                       const char* pkcALIGN  = "center" ,
                       const char* pkcVALIGN = "middle" );

      };  // class TTableCell

    }  // namespace html

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_HTML_TABLE_CELL__
