/*
*  Name:      text_entry.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   HTML text entry
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_TEXT_HTML_TEXT_ENTRY__
#define _MPCL_TEXT_HTML_TEXT_ENTRY__

#include "defs.hh"
#include "tag.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for TEXT.
  namespace text
  {

    ///  Name-space for HTML.
    namespace html
    {

      ///  Forward declaration.
      class TTextEntry;

      ///  Smart pointer to TTextEntry.
      typedef
        TSmartPointer<TTextEntry>
        QTTextEntry;

      ///  Smart pointer to const TTextEntry.
      typedef
        TSmartPointer<const TTextEntry>
        QKTTextEntry;

      /**
      *  HTML text entry.
      *
      *  Attributes added:
      *
      *    "text"       ::= Text before the entry.
      *    "identifier" ::= INPUT.NAME (when INPUT.TYPE=text).
      *    "value"      ::= INPUT.VALUE (when INPUT.TYPE=text).
      *    "size"       ::= INPUT.SIZE (when INPUT.TYPE=text).
      *    "maxlength"  ::= INPUT.MAXLENGTH (when INPUT.TYPE=text).
      */
      class TTextEntry : public TTag
      {

        public:

          //
          //  C O N S T R U C T O R S
          //

          TTextEntry ( const char* pkcIDENTIFIER   ,
                       const char* pkcVALUE   = "" ,
                       const char* pkcTEXT    = "" ,
                       size_t      zSIZE      = 0  ,
                       size_t      zMAXLENGTH = 0  ) :
            TTag (pkcIDENTIFIER, pkcVALUE)
          {
            tAttributeMap ["class-identifier"] = "text-entry";
            tAttributeMap.bind ("text",      pkcTEXT);
            tAttributeMap.bind ("size",      Format ("%u", zSIZE));
            tAttributeMap.bind ("maxlength", Format ("%u", zMAXLENGTH));
            gIsQualified = true;
          }

      };  // class TTextEntry

    }  // namespace html

  }  // namespace text

}  // namespace mpcl


#endif  // not _MPCL_TEXT_HTML_TEXT_ENTRY__
