/*
*  Name:      exceptions.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   PREFS exceptions
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_UTIL_PREFS_EXCEPTIONS__
#define _MPCL_UTIL_PREFS_EXCEPTIONS__

#include "../../exception.hh"
#include "../../error_exception.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for UTIL.
  namespace util
  {

    ///  Name-space for PREFS.
    namespace prefs
    {

      ///  Exception: parent exception class for PREFS.
      class TException : public virtual mpcl::TException {};

      ///  Exception: configuration file not found.
      class TFileErrorException         :
        public virtual mpcl::TException ,
        public         TErrorException  ,
        public         TException
      {

        private:

          ///  Summary description.
          static const char*   _pkcSynopsis;


        public:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Builds the instance with a generic and a (if used) specific description
          *  of the exception.
          *  @param rkyRATIONALE  Specific description.
          *  @param rkyFILE_NAME  File name where the exception has thrown.
          *  @param kiLINE_NUMBER Line number of the former file.
          */
          TFileErrorException ( const string& rkyRATIONALE  ,
                                const string& rkyFILE_NAME  ,
                                const int     kiLINE_NUMBER )                          :
            mpcl::TException (_pkcSynopsis, rkyRATIONALE, rkyFILE_NAME, kiLINE_NUMBER) ,
            TErrorException  ()                                                        ,
            TException       ()                                                        {}

      };  // class TFileErrorException


      ///  Exception: not parameter-able option.
      class TNotParameterAbleException  :
        public virtual mpcl::TException ,
        public TErrorException          ,
        public TException
      {

        private:

          ///  Summary description.
          static const char*   _pkcSynopsis;


        public:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Builds the instance with a generic and a (if used) specific description
          *  of the exception.
          *  @param rkyRATIONALE  Specific description.
          *  @param rkyFILE_NAME  File name where the exception has thrown.
          *  @param kiLINE_NUMBER Line number of the former file.
          */
          TNotParameterAbleException ( const string& rkyRATIONALE  ,
                                       const string& rkyFILE_NAME  ,
                                       const int     kiLINE_NUMBER )                   :
            mpcl::TException (_pkcSynopsis, rkyRATIONALE, rkyFILE_NAME, kiLINE_NUMBER) ,
            TErrorException  ()                                                        ,
            TException       ()                                                        {}

      };  // class TNotParameterAbleException

      ///  Exception: option already defined when adding new options.
      class TOptionAlreadyDefinedException :
        public virtual mpcl::TException    ,
        public         TErrorException     ,
        public         TException
      {

        private:

          ///  Summary description.
          static const char*   _pkcSynopsis;


        public:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Builds the instance with a generic and a (if used) specific description
          *  of the exception.
          *  @param rkyRATIONALE  Specific description.
          *  @param rkyFILE_NAME  File name where the exception has thrown.
          *  @param kiLINE_NUMBER Line number of the former file.
          */
          TOptionAlreadyDefinedException ( const string& rkyRATIONALE  ,
                                           const string& rkyFILE_NAME  ,
                                           const int     kiLINE_NUMBER )               :
            mpcl::TException (_pkcSynopsis, rkyRATIONALE, rkyFILE_NAME, kiLINE_NUMBER) ,
            TErrorException  ()                                                        ,
            TException       ()                                                        {}

      };  // class TOptionAlreadyDefinedException

      ///  Exception: parse error when reading config-file.
      class TParseErrorException        :
        public virtual mpcl::TException ,
        public         TErrorException  ,
        public         TException
      {

        private:

          ///  Summary description.
          static const char*   _pkcSynopsis;


        public:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Builds the instance with a generic and a (if used) specific description
          *  of the exception.
          *  @param rkyRATIONALE  Specific description.
          *  @param rkyFILE_NAME  File name where the exception has thrown.
          *  @param kiLINE_NUMBER Line number of the former file.
          */
          TParseErrorException ( const string& rkyRATIONALE  ,
                                 const string& rkyFILE_NAME  ,
                                 const int     kiLINE_NUMBER )                         :
            mpcl::TException (_pkcSynopsis, rkyRATIONALE, rkyFILE_NAME, kiLINE_NUMBER) ,
            TErrorException  ()                                                        ,
            TException       ()                                                        {}

      };  // class TParseErrorException

      ///  Exception: variable not found in environment.
      class TVariableNotFoundException  :
        public virtual mpcl::TException ,
        public         TErrorException  ,
        public         TException
      {

        private:

          ///  Summary description.
          static const char*   _pkcSynopsis;


        public:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Builds the instance with a generic and a (if used) specific description
          *  of the exception.
          *  @param rkyRATIONALE  Specific description.
          *  @param rkyFILE_NAME  File name where the exception has thrown.
          *  @param kiLINE_NUMBER Line number of the former file.
          */
          TVariableNotFoundException ( const string& rkyRATIONALE  ,
                                       const string& rkyFILE_NAME  ,
                                       const int     kiLINE_NUMBER )                   :
            mpcl::TException (_pkcSynopsis, rkyRATIONALE, rkyFILE_NAME, kiLINE_NUMBER) ,
            TErrorException  ()                                                        ,
            TException       ()                                                        {}

      };  // class TVariableNotFoundException

    }  // namespace prefs

  }  // namespace util

}  // namespace mpcl


#endif  // not _MPCL_UTIL_PREFS_EXCEPTIONS__
