/*
*  Name:      bubble_sort_algorithm.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Bubble sort algorithm
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_UTIL_STRATEGY_BUBBLE_SORT_ALGORITHM__
#define _MPCL_UTIL_STRATEGY_BUBBLE_SORT_ALGORITHM__

#include "sort_algorithm.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for UTIL.
  namespace util
  {

    ///  Name-space for STRATEGY.
    namespace strategy
    {

      /**
      *  Bubble-sort algorithm.
      *
      *  Requires:
      *
      *    TSequence::begin()
      *    TSequence::const_iterator
      *    TSequence::end()
      *    TSequence::iterator
      *    TSequence::size()
      */
      template <typename TSequence>
      class TBubbleSortAlgorithm : public ISortAlgorithm<TSequence>
      {

        public:

          ///  Iterator for sequences.
          typedef
            typename ISortAlgorithm<TSequence>::iterator
            iterator;

          ///  Constant iterator for sequences.
          typedef
            typename ISortAlgorithm<TSequence>::const_iterator
            const_iterator;


        public:

          /**
          *  Applies the bubble-sort algorithm over the sequence of
          *  items \a rtSOURCE_SEQUENCE.
          *  @param rtSOURCE_SEQUENCE Source sequence.
          */
          void execute (TSequence& rtSOURCE_SEQUENCE)
          {

            if ( rtSOURCE_SEQUENCE.size() > 1 )
            {
              iterator         J;
              iterator         I     = rtSOURCE_SEQUENCE.begin();
              const_iterator   ktEnd = rtSOURCE_SEQUENCE.end();

              for (; ( I != ktEnd ) ;++I)
              {
                for (J = I + 1; ( J != ktEnd ) ;++J)
                {
                  if ( *I > *J )
                  {
                    swap (*I, *J);
                  }
                }
              }
            }

          }  // execute()

      };  // class TBubbleSortAlgorithm

    }  // namespace strategy

  }  // namespace util

}  // namespace mpcl


#endif  // not _MPCL_UTIL_STRATEGY_BUBBLE_SORT_ALGORITHM__
