/*
*  Name:      hash_algorithm.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Base hash algorithm
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_UTIL_STRATEGY_HASH_ALGORITHM__
#define _MPCL_UTIL_STRATEGY_HASH_ALGORITHM__


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for UTIL.
  namespace util
  {

    ///  Name-space for STRATEGY.
    namespace strategy
    {

      ///  Base hash algorithm.
      template <typename TKey, typename TValue>
      class IHashAlgorithm
      {

        public:

          ///  Destroys the instance.
          virtual ~IHashAlgorithm() {}

          /**
          *  Applies the hash algorithm over the key \a rktKEY.
          *  @param rktKEY Source key.
          *  @return Value resulted of the execution of this algorithm.
          */
          virtual TValue execute (const TKey& rktKEY) const = 0;

      };  // class IHashAlgorithm

    }  // namespace strategy

  }  // namespace util

}  // namespace mpcl


#endif  // not _MPCL_UTIL_STRATEGY_HASH_ALGORITHM__
