/*
*  Name:      random_string_generator.hh
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Random string generator class
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#ifndef _MPCL_UTIL_STRATEGY_RANDOM_STRING_GENERATOR__
#define _MPCL_UTIL_STRATEGY_RANDOM_STRING_GENERATOR__

#include "general-functions.hh"
#include "../../text/string.hh"


///  Name-space for MPCL.
namespace mpcl
{

  ///  Name-space for UTIL.
  namespace util
  {

    ///  Name-space for STRATEGY.
    namespace strategy
    {

      /**
      *  Random string generator.  It  generates a  string  of a supplied  size
      *  using random characters from a supplied alphabet.
      */
      class TRandomStringGenerator
      {

        private:

          ///  Alphabet for the string generator.
          const TString   kyAlphabet;

          ///  Maximum index value in the alphabet string.
          const TString::size_type   kzMaxAlphabetIndex;


        public:

          //
          //  C O N S T R U C T O R S
          //

          /**
          *  Builds a new instance with alphabet \a pkcALPHABET.
          */
          TRandomStringGenerator (const char* pkcALPHABET) :
            kyAlphabet         (pkcALPHABET)               ,
            kzMaxAlphabetIndex (kyAlphabet.size() - 1)     {}

          /**
          *  Generates  a  random  string  with  size \a kzSIZE  and  formed  using
          *  characters from the alphabet kyALPHABET.
          *  @param kzSIZE Length of the desired string.
          *  @return The random string.
          */
          TString execute (const TString::size_type& kzSIZE)
          {
            MRandomNumberGenerator<TString::size_type>   mRandomNumberGenerator;
            TString                                      yResult;

            for (TString::size_type I = 0; ( I < kzSIZE ) ;++I)
            {
              yResult.append (1, kyAlphabet [mRandomNumberGenerator (kzMaxAlphabetIndex)]);
            }
            return yResult;
          }

      };  // class TRandomStringGenerator

    }  // namespace strategy

  }  // namespace util

}  // namespace mpcl


#endif  // not _MPCL_UTIL_STRATEGY_RANDOM_STRING_GENERATOR__
