/*
*  Name:      defs.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   AUTOMATON definitions
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <cstring>
#include <mpcl/automaton/defs.hh>


///  Name-space for MPCL.
namespace mpcl
{

  namespace automaton
  {

    //
    //  E X P O R T E D   V A R I A B L E S
    //

    //
    //  Tag definitions.
    //

    //
    //  <!-- ... -->
    //
    const char*   pkcCommentTagPattern = "[[:space:]]*<!--%t-->";

    //
    //  <!doctype dfaml [{system="value" | public="value"}]>
    //
    const char*   pkcDOCTYPE_TagPattern_1 = "[[:space:]]*<!doctype"
                                            "[[:space:]]+dfaml[[:space:]]*>";
    const char*   pkcDOCTYPE_TagPattern_2 = "[[:space:]]*<!doctype"
                                            "[[:space:]]+dfaml[[:space:]]+system[[:space:]]*>";
    const char*   pkcDOCTYPE_TagPattern_3 = "[[:space:]]*<!doctype"
                                            "[[:space:]]+dfaml[[:space:]]+system"
                                            "[[:space:]]+%q[[:space:]]*>";
    const char*   pkcDOCTYPE_TagPattern_4 = "[[:space:]]*<!doctype"
                                            "[[:space:]]+dfaml[[:space:]]+public"
                                            "[[:space:]]+%q[[:space:]]*>";

    //
    //  !doctype public versions.
    //
    const char*   pkcDOCTYPE_VERSION_1_0  = "-//mpcl//dtd dfaml 1.0//en";
    const char*   pkcDOCTYPE_VERSION_2_0  = "-//mpcl//dtd dfaml 2.0//en";

    //
    //  <dfaml name="value">...</dfaml>
    //
    const char*   pkcDFAML_TagPattern    = "[[:space:]]*<dfaml"
                                           "[[:space:]]+name[[:space:]]*="
                                           "[[:space:]]*%q"
                                           "[[:space:]]*>[[:blank:]]*\n?";
    const char*   pkcDFAML_EndTagPattern = "[[:space:]]*</dfaml[[:space:]]*>";

    //
    //  <desc>...</desc>
    //
    const char*   pkcDESC_ElementPattern = "[[:space:]]*<desc"
                                           "[[:space:]]*>[[:blank:]]*\n?"
                                           "%t[[:blank:]]*\n?</desc[[:space:]]*>";

    //
    //  <transtbl initial="value">...</transtbl>
    //
    const char*   pkcTRANSTBL_TagPattern    = "[[:space:]]*<transtbl"
                                              "[[:space:]]+initial[[:space:]]*="
                                              "[[:blank:]]*%q"
                                              "[[:space:]]*>[[:blank:]]*\n?";
    const char*   pkcTRANSTBL_EndTagPattern = "[[:space:]]*</transtbl[[:space:]]*>";

    //
    //  <state name="value">...</state>
    //
    const char*   pkcSTATE_TagPattern_1  = "[[:space:]]*<state[[:space:]]+"
                                           "name[[:space:]]*=[[:space:]]*%q"
                                           "[[:space:]]*>";
    const char*   pkcSTATE_TagPattern_2  = "[[:space:]]*<state[[:space:]]+"
                                           "name[[:space:]]*=[[:space:]]*%q[[:space:]]+"
                                           "type[[:space:]]*=[[:space:]]*%q"
                                           "[[:space:]]*>";
    const char*   pkcSTATE_TagPattern_3  = "[[:space:]]*<state[[:space:]]+"
                                           "type[[:space:]]*=[[:space:]]*%q[[:space:]]+"
                                           "name[[:space:]]*=[[:space:]]*%q"
                                           "[[:space:]]*>";
    const char*   pkcSTATE_EndTagPattern = "[[:space:]]*</state[[:space:]]*>";


    //
    //  <transit event="value" next="value">
    //
    const char*   pkcTRANSIT_ElementPattern_1 = "[[:space:]]*<transit"
                                                "[[:space:]]+event[[:space:]]*=[[:space:]]*%q"
                                                "[[:space:]]+next[[:space:]]*=[[:space:]]*%q"
                                                "[[:space:]]*>[[:blank:]]*\n?";
    const char*   pkcTRANSIT_ElementPattern_2 = "[[:space:]]*<transit"
                                                "[[:space:]]+next[[:space:]]*=[[:space:]]*%q"
                                                "[[:space:]]+event[[:space:]]*=[[:space:]]*%q"
                                                "[[:space:]]*>[[:blank:]]*\n?";

    //
    //  <actlist>...</actlist>
    //
    const char*   pkcACTLIST_TagPattern    = "[[:space:]]*<actlist"
                                             "[[:space:]]*>[[:blank:]]*\n?";
    const char*   pkcACTLIST_EndTagPattern = "[[:space:]]*</actlist[[:space:]]*>";

    //
    //  <action state="value" actions="value, value, value...">
    //
    const char*   pkcACTION_ElementPattern_1 = "[[:space:]]*<action"
                                               "[[:space:]]+state[[:space:]]*=[[:space:]]*%q"
                                               "[[:space:]]+actions[[:space:]]*=[[:space:]]*%q"
                                               "[[:space:]]*>[[:blank:]]*\n?";
    const char*   pkcACTION_ElementPattern_2 = "[[:space:]]*<action"
                                               "[[:space:]]+actions[[:space:]]*=[[:space:]]*%q"
                                               "[[:space:]]+state[[:space:]]*=[[:space:]]*%q"
                                               "[[:space:]]*>[[:blank:]]*\n?";

  }  // namespace automaton
  
}  // namespace mpcl
