/*
*  Name:      system.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Base operating system class
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <climits>
#include <iterator>
#include <mpcl/system/system.hh>
#include <mpcl/text/string.hh>


//
//  C O N S T R U C T O R S
//

mpcl::system::ISystem::TMachineDependent::
TMachineDependent (void) :
  eEndianType (eBigEndian) 
{

  using std::size_t;

  size_t   zGuess = 0;

  //
  //  Endian guessing.
  //

  //
  //  zGuess will hold (for "size_t" with 4 bytes
  //  length): 0x04030201
  //
  for (register size_t J = 0; ( J < sizeof (size_t) ) ;++J)
  {
    zGuess |= ((J + 1) << (J * CHAR_BIT));
  }
  
  if ( *((const char*) &zGuess) == sizeof (size_t) )
  {
    eEndianType = eBigEndian;
  }
  else
  {
    eEndianType = eLittleEndian;
  }

}  // TMachineDependent::TMachineDependent()


long int mpcl::system::ISystem::TMachineDependent::
getEndianIndependentLongInt ( EEndianness          eENDIAN_TYPE      ,
                              const unsigned char* pkucSOURCE_BUFFER ,
                              std::size_t          zLENGTH           ) const
{

  long int   liResult  = 0;
  int        iMaxShift = ((zLENGTH - 1) * CHAR_BIT);

  if ( eENDIAN_TYPE == eLittleEndian )
  {
    for (register int J = 0; ( J <= iMaxShift ) ;++pkucSOURCE_BUFFER)
    {
      liResult += (((long int) *pkucSOURCE_BUFFER) << J);
      J        += CHAR_BIT;
    }
  }
  else
  {
    for (register int J = iMaxShift; ( J >= 0 ) ;++pkucSOURCE_BUFFER)
    {
      liResult += (((long int) *pkucSOURCE_BUFFER) << J);
      J        -= CHAR_BIT;
    }
  }
  return liResult;

}  // TMachineDependent::getEndianIndependentLongInt()


std::vector<mpcl::text::TString> mpcl::system::ISystem::
getPathItems (const std::string& rkySOURCE_PATH_COLLECTION) const
{

  using std::back_insert_iterator;
  using std::vector;
  using text::Split;
  using text::TString;

  //
  //  To clarify declarations.
  //  
  typedef
    vector<TString>
    TStringVector;

  TStringVector::iterator   I;
  TStringVector             tPathVector;
  const char                kcDirSeparator = getDirectorySeparator();

  //
  //  Splits string in sub-strings separated by path separators.
  //
  Split ( rkySOURCE_PATH_COLLECTION.begin()                 ,
          rkySOURCE_PATH_COLLECTION.end()                   ,
          getPathSeparator()                                ,
          back_insert_iterator<TStringVector> (tPathVector) );

  //
  //  Adds directory separator if not present.
  //
  for (I = tPathVector.begin(); ( I != tPathVector.end() ) ;++I)
  {
    if ( (*I) [I->length() - 1] != kcDirSeparator )
    {
      I->append (1, kcDirSeparator);
    }
  }
  return tPathVector;

}  // getPathItems()
