/*
*  Name:      clause_tag_string.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Clause-tag string
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <mpcl/text/codegen/clause_tag_string.hh>
#include <mpcl/text/codegen/defs.hh>
#include <mpcl/text/regex/matcher.hh>


//
//  C O N S T R U C T O R S
//

void mpcl::text::codegen::TClauseTagString::
overloadFrom (const TClauseTagString& rkySOURCE_CLAUSE_TAG)
{
  
  assign (rkySOURCE_CLAUSE_TAG);
  gCheckParameters = rkySOURCE_CLAUSE_TAG.gCheckParameters;
  
}  // overloadFrom()


void mpcl::text::codegen::TClauseTagString::
read (std::basic_istream<char_type, traits_type>& rtSOURCE_ISTREAM)
{

  using std::basic_istream;
  using std::ios;
  using text::regex::TMatcher;
  
  bool                                             gHasTarget      = false;
  ios::iostate                                     tInitialIostate = rtSOURCE_ISTREAM.rdstate();
  basic_istream<char_type, traits_type>::pos_type  tInitialPos     = rtSOURCE_ISTREAM.tellg();
  TMatcher                                         tMatcher (rtSOURCE_ISTREAM);

  gCheckParameters = true;
  tMatcher.setCaseSensitiveness (false);

  //
  //  Remove comments if any, and then scans for the first part of the tag.
  //
  while ( tMatcher.scan (pkcCommentTagPattern, NULL) );
  if ( !tMatcher.scan (pkcCLAUSE_TagBegin, NULL) )
  {
    rtSOURCE_ISTREAM.setstate (std::ios::failbit);
  }
  else
  {
    //
    //  Gets the three possible attributes of the tag.
    //
    for (short int I = 0; ( I < 3 ) ;++I)
    {
      if ( !tMatcher.scan (pkcCLAUSE_TagNameAttr, (std::basic_string<char>*) this, NULL) )
      {
        if ( tMatcher.scan (pkcCLAUSE_TagTargetAttr, &yTarget, NULL) > 0 )
        {
          gHasTarget = true;
        }
        else
        {
          if ( !tMatcher.scan (pkcCLAUSE_TagNoCheckAttr, NULL) )
          {
            break;
          }
          else
          {
            gCheckParameters = false;
          }
        }
      }
    }

    //
    //  If it fails to match the ending pattern, then it
    //  changes the state of the stream, showing the error.
    //
    if ( !tMatcher.scan (pkcCLAUSE_TagEnd, NULL) )
    {
      rtSOURCE_ISTREAM.seekg (tInitialPos);
      rtSOURCE_ISTREAM.clear (tInitialIostate);
      rtSOURCE_ISTREAM.setstate (std::ios::failbit);
    }
    else
    {
      //
      //  If clause has target, then appends it to the clause name.
      //
      if ( !gHasTarget )
      {
        yTarget.erase();
      }
      else
      {
        append (pkcTargetSeparator);
        append (yTarget);
      }
    }
  }

}  // read()


//
//  S E L E C T O R S
//

bool mpcl::text::codegen::TClauseTagString::
mustCheckParameters (void) const
{

  return gCheckParameters;
  
}  // mustCheckParameters()


const mpcl::text::TString& mpcl::text::codegen::TClauseTagString::
name (void) const
{
  
  return (const TString&) *this;
  
}  // name()


const mpcl::text::TString& mpcl::text::codegen::TClauseTagString::
target (void) const
{
  
  return yTarget;
  
}  // target()


void mpcl::text::codegen::TClauseTagString::
write (std::basic_ostream<char_type, traits_type>& rtTARGET_OSTREAM) const
{
  
  if ( yTarget.empty() )
  {
    rtTARGET_OSTREAM << "<clause name=\"";
    operator << (rtTARGET_OSTREAM, (std::string) *this);
    rtTARGET_OSTREAM << "\"";
  }
  else
  {
    size_type   zTargetSeparatorPosition;
    TString     yRealName;
    
    if ( npos == (zTargetSeparatorPosition = rfind (pkcTargetSeparator)) )
    {
      throw TBadInstantiateSyntaxException ("malformed name", __FILE__, __LINE__);
    }
    yRealName = substr (0, zTargetSeparatorPosition);
    rtTARGET_OSTREAM << "<clause name=\"" << yRealName << "\" target=\"" << yTarget << "\"";
  }
  if ( !gCheckParameters )
  {
    rtTARGET_OSTREAM << " nocheck";
  }
  rtTARGET_OSTREAM << ">";
  
}  // write()
