/*
*  Name:      test-executable_streamable_dfa.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Test for Executable Streamable Deterministic Finite Automaton
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1999-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <fstream>
#include <mpcl/automaton/executable_streamable_dfa.hh>
#include <mpcl/test.h>
#include <sstream>


using mpcl::automaton::TActionHandler;
using mpcl::automaton::TExecutableStreamableDfa;
using mpcl::event::IAction;
using mpcl::event::TEventHandler;
using mpcl::text::TString;


//
//  L O C A L   T Y P E S
//

class TTestAction : public IAction
{

  public:

    TTestAction (const TString& rkySOURCE_NAME) :
      IAction (rkySOURCE_NAME)                  {}

    bool execute (void)
    {
      if ( !TEST_IN_SILENT_MODE )
      {
        fprintf (hptTestTargetFile, "#ACTION:   %s\n", getName().c_str());
      }
      return true;
    }
    
    int react (void)
    {
      if ( !TEST_IN_SILENT_MODE )
      {
        fprintf (hptTestTargetFile, "#REACTION: %s\n", getName().c_str());
      }
      return 0;
    }
    
};  // class TTestAction


class TTestActionHandler : public TActionHandler<int>
{

  public:

    TTestActionHandler (void) : TActionHandler<int>()
    {
      tActionList.push_back (new TTestAction ("run"));
      tActionList.push_back (new TTestAction ("eat"));
      tActionList.push_back (new TTestAction ("die"));
    }

};  // class TTestActionHandler


///  Main.
int main (void)
{

  TEST_INIT ("tests for class 'TExecutableStreamableDfa'");

  TTestActionHandler                   tActionHandler;
  TEventHandler<int>                   tEventHandler;
  std::basic_ostringstream<char>       tOutputOstringstream;
  std::ifstream                        tInputIfstream ("test-executable_streamable_dfa.dfaml");
  TExecutableStreamableDfa<int, int>   tTestESDFA (tEventHandler, tActionHandler);

  tInputIfstream >> tTestESDFA;
  if ( TEST_IN_SILENT_MODE )
  {
    tOutputOstringstream << tTestESDFA;
  }
  else
  {
    std::cerr << tTestESDFA;
  }
  
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // main()
