/*
*  Name:         test-session.cc
*  Author:       Francisco Rodrigo Escobedo Robles
*  Contributor:  Rafael Jesus Alcantara Perez
*  Summary:      CGI Session tracking testing
*  Date:         $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:     $Revision: 8535 $
*
*  Copyright (C) 2000       Francisco Rodrigo Escobedo Robles <frer@pepix.net>
*  Copyright (C) 2000-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <iostream>
#include <mpcl/net/cgi/cookie.hh>
#include <mpcl/net/cgi/session.hh>
#include <mpcl/text/gmt_date.hh>
#include <mpcl/text/string.hh>
#include <mpcl/test.h>
#include <sstream>


int main (void)
{

  using mpcl::net::cgi::TCookie;
  using mpcl::net::cgi::TSession;
  using mpcl::text::TGmtDate;
  using mpcl::text::TString;  
  using std::basic_ostringstream;

  TEST_INIT ("tests for class 'TSession'");

  basic_ostringstream<char>   tTestOutputStream;
  TSession<TCookie>           tSession
                              (
                                "customer=01743"
                                ";fingerprint=0123456789ABCDEF"
                                ";creditcard=AndromedanExpress"
                                ";shop_cart=0aabn7z3(001=7,002=9)0na00917(57=5,90=6)"
                                ";model_orders=0aabn7z3,lunes(009=1,700=90)"
                                "0aabn7z3,viernes(003=9,090=1)"
                                "6zzabbn7,enero(009=1,030=7)"
                              );
  TString                     ySessionOutputValue
                              (
                                "Set-Cookie: customer=01742\n"
                                "Set-Cookie: fingerprint=0123456789ABCDEF\n"
                                "Set-Cookie: model_orders=0aabn7z3,viernes(090=7)"
                                "6zzabbn7,enero(009=1,030=7)\n"
                                "Set-Cookie: shop_cart=0na00917(57=6,90=6)\n"
                              );

  //
  //  Makes all cookies to stand between sessions.
  //
  tSession.keep ("creditcard");
  tSession.keep ("customer");
  tSession.keep ("fingerprint");
  tSession.keep ("model_orders");
  tSession.keep ("shop_cart");
  TEST_NUMBERS (true, ( tSession.get ("customer") == "01743" ));
  TEST_NUMBERS
  (
    true                                                        ,
    ( tSession.get ("shop_cart", "0na00917") ["57"] == "5" )
  );
  TEST_NUMBERS
  (
    true                                                                       ,
    ( tSession.get ("model_orders", "0aabn7z3", "viernes") ["090"] == "1" )
  );
  tSession.get ("shop_cart",    "0na00917")            ["57"]  = "6";
  tSession.get ("model_orders", "0aabn7z3", "viernes") ["090"] = "7";
  tSession.set ("customer",     "01742");
  tSession.erase ("creditcard");
  tSession.erase ("shop_cart",    "0aabn7z3");
  tSession.erase ("model_orders", "0aabn7z3", "lunes");
  tSession.erase ("model_orders", "0aabn7z3", "viernes", "003");
  tTestOutputStream << tSession;
  TEST_NUMBERS (true, ( tTestOutputStream.str() == ySessionOutputValue ));

  //
  //  Removes 'model_orders' from cookies to stand between sessions.
  //
  tSession.keep ("model_orders", false);
  tTestOutputStream << tSession;
  TEST_NUMBERS (false, ( tTestOutputStream.str() == ySessionOutputValue ));

  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // main()
