/*
*  Name:      test-client.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Test for CORBAL (client)
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 2001-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <cstdio>
#include <fstream>
#include <iostream>
#include <mpcl/net/corba/client_application.hh>
#include <mpcl/net/corba/orb.hh>
#include <mpcl/test.h>
#include "test-sample_producer.hh"


using mpcl::net::corba::TClientApplication;
using mpcl::net::corba::TOrb;
using mpcl::text::TString;


//
//  L O C A L   V A R I A B L E S
//

static const char*   _pkcIorFileName = "test-server.ior.txt";


class TConsumerApplication :
  public virtual TClientApplication<TOrb>
{

  private:

    ///  Sample producer reference type.
    typedef
      mpcl::TSampleProducer_var
      QTSampleProducer;

    ///  Sample producer instance reference (using COS Naming Service).
    QTSampleProducer   qtNamedSampleProducer1;

    ///  Another sample producer instance reference (using COS Naming Service).
    QTSampleProducer   qtNamedSampleProducer2;

    ///  Sample producer instance reference.
    QTSampleProducer   qtSampleProducer;


  public:
    
    TConsumerApplication ( const char* pkcNAME    ,
                           const char* pkcRELEASE ,
                           TOrb&       rtORB      )         :
      TClientApplication<TOrb> (pkcNAME, pkcRELEASE, rtORB) {}

    void initialize (void);

    int start (void);


  public:

    TString programFileName (void) const
    {
      return "test-client";
    }

};  // class TConsumerApplication


//
//  C O N S T R U C T O R S
//

void TConsumerApplication::initialize (void)
{

  std::string     yIor;
  std::ifstream   tIfstream (_pkcIorFileName);

  tIfstream >> yIor;
  tIfstream.close();
  std::remove (_pkcIorFileName);
  qtNamedSampleProducer1 =
    rtOrb.request<mpcl::TSampleProducer, QTSampleProducer> ("corbaname:rir:#mpcl/test-server/sample_producer_1.object");
  qtNamedSampleProducer2 =
    rtOrb.request<mpcl::TSampleProducer, QTSampleProducer> ("corbaname:rir:#mpcl/test-server/sample_producer_2.object");
  qtSampleProducer =
    rtOrb.request<mpcl::TSampleProducer, QTSampleProducer> (yIor.c_str());

}  // initialize()


int TConsumerApplication::start (void)
{ 

  TEST_INIT ("tests for class 'TConsumerApplication'");

  //
  //  Instance qtSampleProducer starts its internal counter at 0.
  //
  TEST_NUMBERS (0, qtSampleProducer->get());
  TEST_NUMBERS (1, qtSampleProducer->get());
  TEST_NUMBERS (2, qtSampleProducer->get());
  TEST_NUMBERS (3, qtSampleProducer->get());

  //
  //  Instance qtNamedSampleProducer1 starts its internal counter at 10.
  //
  TEST_NUMBERS (10, qtNamedSampleProducer1->get());
  TEST_NUMBERS (11, qtNamedSampleProducer1->get());
  TEST_NUMBERS (12, qtNamedSampleProducer1->get());
  TEST_NUMBERS (13, qtNamedSampleProducer1->get());

  //
  //  Instance qtNamedSampleProducer2 starts its internal counter at 20.
  //
  TEST_NUMBERS (20, qtNamedSampleProducer2->get());
  TEST_NUMBERS (21, qtNamedSampleProducer2->get());
  TEST_NUMBERS (22, qtNamedSampleProducer2->get());
  TEST_NUMBERS (23, qtNamedSampleProducer2->get());

  //
  //  Finishes ORB.
  //
  qtNamedSampleProducer1->finish();

  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // start()


///  Main. This test must be ran after server (test-server).
int main (int argc, const char** argv)
{

  TEST_INIT ("tests for CORBA as client");
  try
  {
    TOrb                   tOrb (argc, argv);
    TConsumerApplication   tApplication ("test-client", "0.0.0", tOrb);
    
    tApplication.initialize();
    TEST_FUNCTION (tApplication.start());
  }
  catch (CORBA::SystemException&)
  {
    std::cerr << "ORB; caught CORBA::SystemException" << std::endl;
    TEST_FAIL;
  }
  catch (CORBA::Exception&)
  {
    std::cerr << "ORB; caught CORBA::Exception" << std::endl;
    TEST_FAIL;
  }
  catch (const mpcl::TException& rktEXCEPTION)
  {
    std::cerr << rktEXCEPTION;
    TEST_FAIL;
  }
  catch (std::exception& rktEXCEPTION)
  {
    std::cerr << rktEXCEPTION.what();
    TEST_FAIL;
  }
  catch (...)
  {
    std::cerr << "caught unknown exception" << std::endl;
    TEST_FAIL;
  }
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // main()
