/*
*  Name:      test-variable_argument_array.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Test for Variable argument array
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <iostream>
#include <mpcl/test.h>
#include <mpcl/util/variable_argument_array.hh>

using mpcl::util::TVariableArgumentArray;


class TItem
{

  public:

    int   iValue;
    

  public:

    TItem (int iSOURCE_VALUE) :
      iValue (iSOURCE_VALUE)  {}

    TItem (void) :
      iValue (0) {}

};  // class TItem


static int _TestForInt (int iFIRST_PARAMETER...)
{

  va_list                       tVa_list;
  TVariableArgumentArray<int>   tVAA_Int;

  TEST_INIT ("tests for class 'TVariableArgumentArray<int>'");

  va_start (tVa_list, iFIRST_PARAMETER);
  tVAA_Int.initialize (tVa_list);
  TEST_NUMBERS (iFIRST_PARAMETER, 0);
  TEST_NUMBERS (tVAA_Int [0],     1);
  TEST_NUMBERS (tVAA_Int [1],     2);
  TEST_NUMBERS (tVAA_Int [2],     3);
  TEST_NUMBERS (tVAA_Int [3],     4);
  TEST_NUMBERS (tVAA_Int [3],     4);
  TEST_NUMBERS (tVAA_Int [2],     3);
  TEST_NUMBERS (tVAA_Int [1],     2);
  TEST_NUMBERS (tVAA_Int [0],     1);
  TEST_NUMBERS (tVAA_Int.size(),  4);
  
  try
  {
    TEST_NUMBERS (tVAA_Int [4], 1);
    TEST_FAIL;
  }
  catch (...)
  {
    TEST_PASS;
  }  
  try
  {
    TEST_NUMBERS (tVAA_Int [5], 1);
    TEST_FAIL;
  }
  catch (...)
  {
    TEST_PASS;
  }  
  
  va_end (tVa_list);
  
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // _TestForInt()


static int _TestForString (const char* pkcFIRST_PARAMETER...)
{

  va_list                         tVa_list;
  TVariableArgumentArray<char*>   tVAA_PChar;

  TEST_INIT ("tests for class 'TVariableArgumentArray<char*>'");

  va_start (tVa_list, pkcFIRST_PARAMETER);
  tVAA_PChar.initialize (tVa_list);
  TEST_STRINGS (pkcFIRST_PARAMETER, "0");
  TEST_STRINGS (tVAA_PChar [0],     "1");
  TEST_STRINGS (tVAA_PChar [1],     "2");
  TEST_STRINGS (tVAA_PChar [2],     "3");
  TEST_STRINGS (tVAA_PChar [3],     "4");
  TEST_STRINGS (tVAA_PChar [3],     "4");
  TEST_STRINGS (tVAA_PChar [2],     "3");
  TEST_STRINGS (tVAA_PChar [1],     "2");
  TEST_STRINGS (tVAA_PChar [0],     "1");
  TEST_NUMBERS (tVAA_PChar.size(),  4);
  
  try
  {
    TEST_STRINGS (tVAA_PChar [4], "1");
    TEST_FAIL;
  }
  catch (...)
  {
    TEST_PASS;
  }  
  try
  {
    TEST_STRINGS (tVAA_PChar [5], "1");
    TEST_FAIL;
  }
  catch (...)
  {
    TEST_PASS;
  }  
  
  va_end (tVa_list);
  
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // _TestForString()


static int _TestForItem (TItem* ptFIRST_PARAMETER_ITEM...)
{

  va_list                          tVa_list;
  TVariableArgumentArray<TItem*>   tVAA_PTItem;

  TEST_INIT ("tests for class 'TVariableArgumentArray<TIem*>'");

  va_start (tVa_list, ptFIRST_PARAMETER_ITEM);
  tVAA_PTItem.initialize (tVa_list);
  TEST_NUMBERS (ptFIRST_PARAMETER_ITEM->iValue, 0);
  TEST_NUMBERS (tVAA_PTItem [0]->iValue,        1);
  TEST_NUMBERS (tVAA_PTItem [1]->iValue,        2);
  TEST_NUMBERS (tVAA_PTItem [2]->iValue,        3);
  TEST_NUMBERS (tVAA_PTItem [3]->iValue,        4);
  TEST_NUMBERS (tVAA_PTItem [3]->iValue,        4);
  TEST_NUMBERS (tVAA_PTItem [2]->iValue,        3);
  TEST_NUMBERS (tVAA_PTItem [1]->iValue,        2);
  TEST_NUMBERS (tVAA_PTItem [0]->iValue,        1);
  TEST_NUMBERS (tVAA_PTItem.size(),             4);
  
  try
  {
    TEST_NUMBERS (tVAA_PTItem [4]->iValue, 1);
    TEST_FAIL;
  }
  catch (...)
  {
    TEST_PASS;
  }  
  try
  {
    TEST_NUMBERS (tVAA_PTItem [5]->iValue, 1);
    TEST_FAIL;
  }
  catch (...)
  {
    TEST_PASS;
  }  
  
  va_end (tVa_list);
  
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // _TestForItem()


int main (void)
{

  TEST_INIT ("tests for class 'TVariableArgumentArray'");

  TItem                            tItem0 (0);
  TItem                            tItem1 (1);
  TItem                            tItem2 (2);
  TItem                            tItem3 (3);
  TItem                            tItem4 (4);
  TVariableArgumentArray<TItem*>   tVAA_PTItem;

  TEST_FUNCTION (_TestForInt    (0, 1, 2, 3, 4, NULL));
  TEST_FUNCTION (_TestForString ("0", "1", "2", "3", "4", NULL));
  TEST_FUNCTION (_TestForItem   (&tItem0, &tItem1, &tItem2, &tItem3, &tItem4, NULL));

  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // main()
