/*
*  Name:      cdmlc.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   CDML compiler
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 1994-2002  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <exception>
#include <iostream>
#include <mpcl/text/codegen/pattern_based_code_generator.hh>
#include <mpcl/util/prefs/config_processor.hh>


//
//  L O C A L   V A R I A B L E S
//

///  Program version string.
static const char*   _pkcVersion = "0.0.5";


//
//  L O C A L   F U N C T I O N S
//

///  Main program.
int main (int argc, const char** argv)
{

  using mpcl::text::codegen::TPatternBasedCodeGenerator;
  using mpcl::text::TString;
  using mpcl::util::prefs::TConfigProcessor;
  using std::cerr;
  using std::cout;
  using std::endl;

  TPatternBasedCodeGenerator   tCompilerPbcg;
  TConfigProcessor             tConfigProcessor (argc, argv);
  int                          iExitCode = 0;

  //
  //  Create options with their default values.
  //
  tConfigProcessor.addOption ("cdml-path", "m", ".");
  tConfigProcessor.addOption ("help",      "h");
  tConfigProcessor.addOption ("version",   "V");
  tConfigProcessor.setUsageStringHeader         ("Usage:  cdmlc [OPTION]... FILE\n\nOptions:");
  tConfigProcessor ["cdml-path"].setUsageString ("Path for searching CDML documents");
  tConfigProcessor ["help"].setUsageString      ("Print usage information");
  tConfigProcessor ["version"].setUsageString   ("Print version information");
  tConfigProcessor.processOptions();

  if ( tConfigProcessor ["help"].isAtCmdLine() )
  {
    TString   yUsageString (tConfigProcessor.formatUsageString());

    cout << yUsageString;
  }
  else if ( tConfigProcessor ["version"].isAtCmdLine() )
  {
    cout << _pkcVersion << endl;
  }
  else if ( !tConfigProcessor.hasArguments() )
  {
    cerr << "cdmlc: there is no input file\n";
    iExitCode = 1;
  }
  else
  {
    try
    {
      //
      //  Reads CDML, and then removes all superfluous information.
      //
      tCompilerPbcg.setCdmlPath (tConfigProcessor ["cdml-path"].getValue());
      tCompilerPbcg.loadFrom (tConfigProcessor.argumentValue (0));
      tCompilerPbcg.compile();

      //
      //  Removes description to accelerate read stage.
      //
      tCompilerPbcg.setDescription ("");
      cout << tCompilerPbcg;
    }
    catch (const mpcl::TException& rktEXCEPTION)
    {
      iExitCode = 3;
      cerr << rktEXCEPTION;
    }
    catch (const std::exception& rktEXCEPTION)
    {
      iExitCode = 2;
      cerr << rktEXCEPTION.what() << endl;
    }
    catch (...)
    {
      iExitCode = 1;
      cerr << mpcl::TException ("unhandled exception", NULL, __FILE__, __LINE__);
    }
  }
  return iExitCode;

}  // main()
