/*
*  Name:      TEvent.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Event class for the model paradigm
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 2003  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for MODEL (from MVC paradigm) design patterns.
package org.mpcl.designpatterns.mvc.model;

import java.util.EventObject;


/**
*  Model  event class.  All events  are constructed  with a  reference  to  the
*  "source" object,  that is logically  deemed to be the object  upon which the
*  event in question initially  occurred  upon.  Besides  that,  this class  is
*  constructed with another reference to a \a TAccountTemplates._TTuple object.
*  @see TTuple
*/
public class TEvent extends EventObject
{

  ///  Type.
  private int   iType;

  ///  Tuple.
  private TTuple   tTuple;

  /**
  *  Event types.
  *  @see #getType()
  */
  public static class _TType
  {
    ///  Identifies the addition of a tuple.
    public static final int   _kiTupleAdded = 0;

    ///  Identifies the removal of a tuple.
    public static final int   _kiTupleRemoved = 1;

    ///  Identifies changes in a tuple.
    public static final int   _kiTupleUpdated = 2;
  }


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Builds a new instance.
  *  @param tSOURCE The object on which the event initially occurred.
  *  @param tTUPLE  The tuple.
  *  @param iTYPE   The type of the event.
  */
  public TEvent (Object tSOURCE, TTuple tTUPLE, int iTYPE)
  {
    super (tSOURCE);
    tTuple = tTUPLE;
    iType  = iTYPE;
  }


  //
  //  S E L E C T O R S
  //

  /**
  *  Returns the tuple that has been modified.
  *  @return The modified tuple.
  */
  public TTuple getTuple()
  {
    return tTuple;
  }

  /**
  *  Returns the event type.
  *  @return An int representing the type value.
  *  @see _TType
  */
  public int getType()
  {
    return iType;
  }

}  // class TEvent
