/*
*  Name:      TTupleMutableObservable.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Tuple mutable observable class for the model paradigm
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 2003  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for MODEL (from MVC paradigm) design patterns.
package org.mpcl.designpatterns.mvc.model;

import org.mpcl.designpatterns.behavioral.TMutableObservable;


/**
*  Model mutable observable tuple class.
*  It  represents a  model tuple  object  that  the application  wants to  have
*  mutated and observed.
*  @see org.mpcl.designpatterns.behavioral.TMutableObservable
*/
public class TTupleMutableObservable extends TMutableObservable
{

  ///  Tuple.
  private TTuple   tTuple;


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Builds a new instance.
  *  @param tTUPLE The tuple object to be observed and mutated.
  */
  public TTupleMutableObservable (TTuple tTUPLE)
  {
    tTuple = tTUPLE;
  }

  /**
  *  Sets the model tuple.
  *  @param tTUPLE Model tuple.
  */
  public void setTuple (TTuple tTUPLE)
  {
    tTuple = tTUPLE;
  }


  //
  //  S E L E C T O R S
  //

  /**
  *  Returns the model tuple.
  *  @return The model tuple.
  */
  public TTuple getTuple()
  {
    return tTuple;
  }

}  // class TTupleMutableObservable
