/*
*  Name:      TColor.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Color class
*  Date:      $Date: 2004-08-02 19:20:39 +0200 (lun, 02 ago 2004) $
*  Revision:  $Revision: 9838 $
*
*  Copyright (C) 2003-2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for NUI (Native User Interface).
package org.mpcl.nui;

import java.awt.Color;


///  Color class.
public class TColor extends Color
{

  //
  //  C O N S T R U C T O R S
  //

  public static TColor _brighter (Color tCOLOR, int iINCREMENT)
  {
    int   iRed   = Math.min (255, tCOLOR.getRed()   + iINCREMENT);
    int   iGreen = Math.min (255, tCOLOR.getGreen() + iINCREMENT);
    int   iBlue  = Math.min (255, tCOLOR.getBlue()  + iINCREMENT);

    return new TColor (iRed, iGreen, iBlue, tCOLOR.getAlpha());
  }

  public static TColor _darker (Color tCOLOR, int iDECREMENT)
  {
    int   iRed   = Math.max (0, tCOLOR.getRed()   - iDECREMENT);
    int   iGreen = Math.max (0, tCOLOR.getGreen() - iDECREMENT);
    int   iBlue  = Math.max (0, tCOLOR.getBlue()  - iDECREMENT);

    return new TColor (iRed, iGreen, iBlue, tCOLOR.getAlpha());
  }

  /**
  *  Creates  an opaque  sRGB color with  the specified  red,  green,  and blue
  *  values in the range (0 - 255).
  *  @param iRED   Red value.
  *  @param iGREEN Green value.
  *  @param iBLUE  Blue value.
  */
  public TColor (int iRED, int iGREEN, int iBLUE)
  {
    super (iRED, iGREEN, iBLUE);
  }

  /**
  *  Creates  an opaque  sRGB color with the specified red,  green,  blue,  and
  *  alpha values in the range (0 - 255).
  *  @param iRED   Red value.
  *  @param iGREEN Green value.
  *  @param iBLUE  Blue value.
  *  @param iALPHA Alpha value.
  */
  public TColor (int iRED, int iGREEN, int iBLUE, int iALPHA)
  {
    super (iRED, iGREEN, iBLUE, iALPHA);
  }

  public TColor brighter (int iINCREMENT)
  {
    int   iRed   = Math.min (255, getRed()   + iINCREMENT);
    int   iGreen = Math.min (255, getGreen() + iINCREMENT);
    int   iBlue  = Math.min (255, getBlue()  + iINCREMENT);

    return new TColor (iRed, iGreen, iBlue, getAlpha());
  }

  public TColor darker (int iDECREMENT)
  {
    int   iRed   = Math.max (0, getRed()   - iDECREMENT);
    int   iGreen = Math.max (0, getGreen() - iDECREMENT);
    int   iBlue  = Math.max (0, getBlue()  - iDECREMENT);

    return new TColor (iRed, iGreen, iBlue, getAlpha());
  }

}  // class TColor
