/*
*  Name:      TDoubleInputVerifier.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Double input validator for 'JTextComponent' derived classes
*  Date:      $Date: 2004-10-12 23:01:07 +0200 (mar, 12 oct 2004) $
*  Revision:  $Revision: 10259 $
*
*  Copyright (C) 2001-2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for NUI (Native User Interface).
package org.mpcl.nui;

import java.text.ParseException;
import javax.swing.JComponent;
import javax.swing.text.JTextComponent;
import org.mpcl.text.TNumberTranslator;


/**
*  Double input validator class for text fields.
*  @see javax.swing.text.JTextComponent.
*/
public class TDoubleInputVerifier extends TAbstractInputVerifier
{

  ///  True if the number to be verified can be zero.
  private boolean   gCanBeZero;

  ///  Number translator.
  private TNumberTranslator   tNumberTranslator;


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Builds a new instance.
  *  @param yERROR_MESSAGE Error message for not validating this verifier.
  */
  public TDoubleInputVerifier (String yERROR_MESSAGE)
  {
    this (yERROR_MESSAGE, true);
  }

  /**
  *  Builds a new instance.
  *  @param yERROR_MESSAGE Error message for not validating this verifier.
  *  @param gCAN_BE_ZERO   True if the number can be zero.
  */
  public TDoubleInputVerifier (String yERROR_MESSAGE, boolean gCAN_BE_ZERO)
  {
    super (yERROR_MESSAGE);
    gCanBeZero        = gCAN_BE_ZERO;
    tNumberTranslator = new TNumberTranslator();
  }


  //
  //  S E L E C T O R S
  //

  /**
  *  Checks whether the JComponent's input is a valid double.
  *  @param tCOMPONENT Component to check.
  *  @return True if it holds a valid double number.
  *  @pre ( tCOMPONENT instanceOf JTextComponent )
  *  @see java.swing.text.JTextComponent.
  */
  public boolean verify (JComponent tCOMPONENT)
  {

    double           dValue         = 0;
    boolean          gVerified      = true;
    JTextComponent   tTextComponent = (JTextComponent) tCOMPONENT;
    String           yText          = tTextComponent.getText().trim();

    if ( yText.length() == 0 )
    {
      tTextComponent.setText ("0");
    }
    else
    {
      try
      {
        dValue = tNumberTranslator.toDouble (yText);
      }
      catch (final ParseException ktEXCEPTION)
      {
        gVerified = false;
      }
    }
    if ( gVerified && !gCanBeZero )
    {
      gVerified = ( dValue != 0 );
    }
    return gVerified;

  }  // verify()

}  // class TDoubleInputVerifier
