/*
*  Name:      TRegexInputVerifier.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Regular expression input validator for 'JTextComponent' derived classes
*  Date:      $Date: 2004-10-12 23:01:07 +0200 (mar, 12 oct 2004) $
*  Revision:  $Revision: 10259 $
*
*  Copyright (C) 2003-2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for NUI (Native User Interface).
package org.mpcl.nui;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.swing.JComponent;
import javax.swing.text.JTextComponent;


/**
*  Regular expression validator class for text components.
*  @see javax.swing.text.JTextComponent.
*/
public class TRegexInputVerifier extends TAbstractInputVerifier
{

  ///  Regex list.
  private List   tRegexList;


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Builds a new instance.
  *  @param yERROR_MESSAGE Error message for not validating this verifier.
  */
  public TRegexInputVerifier (String yERROR_MESSAGE)
  {
    super (yERROR_MESSAGE);

    tRegexList = new ArrayList();
  }

  /**
  *  Adds a new regular expression to be checked for validating input.
  *  @param yREGEX The regular expression string to be added.
  */
  public void addRegex (String yREGEX)
  {
    tRegexList.add (yREGEX);
  }


  //
  //  S E L E C T O R S
  //

  /**
  *  Checks whether the JComponent's input matches any of the regular expressions.
  *  @param tCOMPONENT Component to check.
  *  @return True if it matches any of the regular expressions.
  *  @pre ( tCOMPONENT instanceOf JTextField )
  *  @see java.swing.JTextField.
  */
  public boolean verify (JComponent tCOMPONENT)
  {

    Iterator         I;
    String           yInput;
    boolean          gVerify        = true;
    JTextComponent   tTextComponent = (JTextComponent) tCOMPONENT;

    yInput = tTextComponent.getText();
    I      = tRegexList.iterator();
    while ( I.hasNext() )
    {
      gVerify = ( yInput.matches ((String) I.next()) );
      if ( gVerify )
      {
        break;
      }
    }
    return gVerify;

  }  // verify()

}  // class TRegexInputVerifier
