/*
*  Name:      TRule.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Class that implements a simple two line rule
*  Date:      $Date: 2004-02-26 01:28:54 +0100 (jue, 26 feb 2004) $
*  Revision:  $Revision: 8966 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for NUI (Native User Interface).
package org.mpcl.nui;

import java.awt.Color;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Rectangle;
import javax.swing.JComponent;
import javax.swing.UIManager;


/**
*  Rule.
*  @see javax.swing.JSeparator
*/
public class TRule extends JComponent
{

  //
  //  S E L E C T O R S
  //

  /**
  *  Paints the border for the specified component with the specified position
  *  and size.
  *  @param tGRAPHICS The paint graphics.
  */
  protected void paintChildren (Graphics tGRAPHICS)
  {
    Dimension   tDimension = getSize();
    int         iLineY     = (tDimension.height - 1) / 2;

    tGRAPHICS.setColor (UIManager.getColor ("Separator.foreground"));
    tGRAPHICS.drawLine (0, iLineY, tDimension.width, iLineY);
    tGRAPHICS.setColor (UIManager.getColor ("Separator.background"));
    tGRAPHICS.drawLine (0, iLineY + 1, tDimension.width, iLineY + 1);
    super.paintChildren (tGRAPHICS);
  }


  //
  //  S E L E C T O R S
  //

  /**
  *  Returns the minimum size of this component.
  *  @return An instance  of \a Dimension that  represents  the minimum size of
  *          this component.
  *  @see javax.swing.JComponent#getMinimumSize()
  */
  public Dimension getMinimumSize()
  {
    Dimension   tDimension;

    tDimension        = super.getMinimumSize();
    tDimension.height = Math.max (2, tDimension.height);
    return tDimension;
  }

  /**
  *  Returns the preferred size of this component.
  *  @return An instance  of \a Dimension that represents the preferred size of
  *          this component.
  *  @see javax.swing.JComponent#getPreferredSize()
  */
  public Dimension getPreferredSize()
  {
    Dimension   tDimension;

    tDimension        = super.getPreferredSize();
    tDimension.height = 2;
    return tDimension;
  }

}  // class TRule
