/*
*  Name:      TSelecterFocusListener.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Focus listener for text components that makes them selected when focused
*  Date:      $Date: 2004-03-06 16:49:27 +0100 (sáb, 06 mar 2004) $
*  Revision:  $Revision: 9055 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for NUI (Native User Interface).
package org.mpcl.nui;

import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import javax.swing.text.JTextComponent;


/**
*  Focus listener for \a JTextComponent objects to make all its text,  selected
*  when focused (and de-selected when the focus is lost.
*  @warning It is only usable with \a JTextComponent objects (and sons).
*/
public class TSelecterFocusListener implements FocusListener
{

  /**
  *  Invoked when a component gains the keyboard focus.
  *  @param tFOCUS_EVENT The \a FocusEvent object.
  *  @see java.awt.event.FocusListener#focusGained()
  */
  public void focusGained (FocusEvent tFOCUS_EVENT)
  {
    ((JTextComponent) tFOCUS_EVENT.getSource()).selectAll();
  }

  /**
  *  Invoked when a component loses the keyboard focus.
  *  @param tFOCUS_EVENT The \a FocusEvent object.
  *  @see java.awt.event.FocusListener#focusLost()
  */
  public void focusLost (FocusEvent tFOCUS_EVENT)
  {
    ((JTextComponent) tFOCUS_EVENT.getSource()).select (0, 0);
  }

}  // class TSelecterFocusListener
