/*
*  Name:      TAbstractBrowserPanel.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Abstract browser panel class
*  Date:      $Date: 2004-11-13 03:35:03 +0100 (sáb, 13 nov 2004) $
*  Revision:  $Revision: 10439 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for NUI PANEL.
package org.mpcl.nui.panel;

import java.util.Observable;
import javax.swing.JPanel;
import org.mpcl.designpatterns.behavioral.ICasualObserver;
import org.mpcl.nui.IBrowser;


/**
*  Abstract observer  panel.  This  class edits  the model  using  the observer
*  paradigm.
*  @see java.util.Observable
*  @see org.mpcl.design.behavioral.ICasualObserver
*/
public abstract class TAbstractBrowserPanel
  extends    JPanel
  implements IBrowser, ICasualObserver
{

  //
  //  C O N S T R U C T O R S
  //
  
  /**
  *  Updates source view elements from the default model.
  *  @see org.mpcl.nui.IBrowser#load()
  */
  public void load()
  {
    load (null);
  }

  /**
  *  Updates source view elements from the model related to \a tOBSERVABLE.
  *  @param tOBSERVABLE The observed object (can be null).
  *  @see org.mpcl.nui.IBrowser#load (Observable)
  */
  public abstract void load (Observable tOBSERVABLE);

  /**
  *  This method is called from the observed object \a tOBSERVABLE to advise of
  *  a change in that object.
  *  @param tOBSERVABLE Observed object.
  *  @param tARGUMENT   An argument.
  *  @see java.util.Observable
  *  @see java.util.Observer
  */
  public void update (Observable tOBSERVABLE, Object tARGUMENT)
  {
    load (tOBSERVABLE);
    repaint();
  }

}  // class TAbstractBrowserPanel
