/*
*  Name:      TGradientPanel.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Panel class with a gradient background
*  Date:      $Date: 2005-04-05 15:08:27 +0200 (mar, 05 abr 2005) $
*  Revision:  $Revision: 11007 $
*
*  Copyright (C) 2003-2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for NUI PANEL.
package org.mpcl.nui.panel;

import java.awt.Color;
import java.awt.GradientPaint;
import java.awt.Graphics2D;
import java.awt.Graphics;
import java.awt.Rectangle;
import javax.swing.JPanel;


///  Panel class with a gradient background.
public class TGradientPanel extends JPanel
{

  ///  First color for the gradient.
  private Color   tFromColor;

  ///  Gradient paint.
  private GradientPaint   tGradientPaint;

  ///  Last color for the gradient.
  private Color   tUntilColor;


  //
  //  C O N S T R U C T O R S
  //

  ///  Updates the gradient paint.
  private void updateGradientPaint()
  {
    tGradientPaint =
      new GradientPaint (0, 0, tFromColor, getWidth(), getHeight(), tUntilColor);
  }


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Builds a new instance. It paints the background with a gradient from color
  *  \a tFROM_COLOR until color \a tUNTIL_COLOR.
  *  @param tFROM_COLOR  First gradient color.
  *  @param tUNTIL_COLOR Last gradient color.
  */
  public TGradientPanel (Color tFROM_COLOR, Color tUNTIL_COLOR)
  {
    super();
    tFromColor  = tFROM_COLOR;
    tUntilColor = tUNTIL_COLOR;
    updateGradientPaint();
  }

  /**
  *  Moves and resizes this component.  The new location of the top-left corner
  *  is specified  by \a iX and \a iY;  the  new size is specified by \a iWIDTH
  *  and \a iHEIGHT.
  *  @param iX      The new x-coordinate of this component.
  *  @param iY      The new y-coordinate of this component.
  *  @param iWIDTH  The new width of this component.
  *  @param iHEIGHT The new height of this component.
  */
  public void setBounds (int iX, int iY, int iWIDTH, int iHEIGHT)
  {
    super.setBounds (iX, iY, iWIDTH, iHEIGHT);
    updateGradientPaint();
  }

  /**
  *  Moves and resizes this component to conform  to the new bounding rectangle
  *  \a tRECTANGLE.   This   component's   new   position   is   specified   by
  *  \a tRECTANGLE.x and  \a tRECTANGLE.y,   and its  new size is  specified by
  *  \a tRECTANGLE.width and \a tRECTANGLE.height.
  *  @param tRECTANGLE The new bounding rectangle for this component.
  *  @see getSize(), setBounds(int, int, int, int)
  */
  public void setBounds (Rectangle tRECTANGLE)
  {
    super.setBounds (tRECTANGLE);
    updateGradientPaint();
  }


  //
  //  S E L E C T O R S
  //

  protected void paintComponent (Graphics tGRAPHICS)
  {
    Graphics2D   tGraphics2D = (Graphics2D) tGRAPHICS;

    tGraphics2D.setPaint (tGradientPaint);
    tGraphics2D.fill (new Rectangle (0, 0, getWidth(), getHeight()));
  }

}  // class TGradientPanel
