/*
*  Name:      TTitledGradientPanel.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Panel class with a gradient background and a title
*  Date:      $Date: 2005-04-05 15:08:27 +0200 (mar, 05 abr 2005) $
*  Revision:  $Revision: 11007 $
*
*  Copyright (C) 2003  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for NUI PANEL.
package org.mpcl.nui.panel;

import java.awt.BorderLayout;
import java.awt.Color;
import javax.swing.BorderFactory;
import javax.swing.border.Border;
import javax.swing.JLabel;


/**
*  Panel class with a gradient background and a title label. If you want to add
*  another border,  you should make a  compound border with the current border.
*/
public class TTitledGradientPanel extends TGradientPanel
{

  ///  Title label.
  private JLabel   tTitleLabel;


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Builds a new instance. It paints the background with a gradient from color
  *  \a tFROM_COLOR until color \a tUNTIL_COLOR, and onto it, a text label with
  *  \a yTITLE and with color \a tTITLE_COLOR is painted.
  *  @param yTITLE       Title.
  *  @param tTITLE_COLOR Title color.
  *  @param tFROM_COLOR  First gradient color.
  *  @param tUNTIL_COLOR Last gradient color.
  */
  public TTitledGradientPanel ( String yTITLE       ,
                                Color  tTITLE_COLOR ,
                                Color  tFROM_COLOR  ,
                                Color  tUNTIL_COLOR )
  {
    super (tFROM_COLOR, tUNTIL_COLOR);

    tTitleLabel = new JLabel (yTITLE, JLabel.LEFT);
    tTitleLabel.setForeground (tTITLE_COLOR);
    setBorder (BorderFactory.createEmptyBorder (6, 6, 6, 6));
    setLayout (new BorderLayout());
    add (tTitleLabel, BorderLayout.WEST);
  }

}  // class TGradientPanel
