/*
*  Name:      ITableAppearanceModel.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Table appearance model interface
*  Date:      $Date: 2004-05-28 02:37:43 +0200 (vie, 28 may 2004) $
*  Revision:  $Revision: 9454 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for TABLE (table support classes).
package org.mpcl.nui.table;

import java.awt.Dimension;


///  Table width model class to let the table know the minimum column widths.
public interface ITableAppearanceModel
{

  //
  //  S E L E C T O R S
  //

  /**
  *  Returns the minimum width for a table column.
  *  @param iCOLUMN Column index on the table.
  *  @return The minimum column width for column at index \a iCOLUMN.
  */
  public int getColumnMinWidth (int iCOLUMN);

  /**
  *  Returns the preferred scrollable viewport size for the table.
  *  @return The preferred scrollable viewport size.
  *  @see javax.swing.JTable#setPreferredScrollableViewportSize()
  */
  public Dimension getPreferredScrollableViewportSize();

  /**
  *  Gets the tool-tip for the cell at row \a iROW and column \a iCOLUMN.
  *  @param iROW    Row index.
  *  @param iCOLUMN Column index.
  *  @return The tool-tip.
  */
  public String getToolTipText (int iROW, int iCOLUMN);

}  // interface ITableAppearanceModel
