/*
*  Name:      ITableModelFilter.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Filter for table models
*  Date:      $Date: 2005-03-15 00:48:45 +0100 (mar, 15 mar 2005) $
*  Revision:  $Revision: 10891 $
*
*  Copyright (C) 2005  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for TABLE (table support classes).
package org.mpcl.nui.table;

import javax.swing.table.TableModel;


///  Table model filter interface.
public interface ITableModelFilter
{
  /**
  *  Returns the filtered value of the table model at (\a iROW, \a iCOLUMN).
  *  @param tTABLE_MODEL The table model object.
  *  @param iROW         The row index.
  *  @param iCOLUMN      The column index.
  *  @return The value of the cell at \a iROW, \a iCOLUMN in the table model.
  *  @see javax.swing.table.TableModel#getValueAt(int,int)
  */
  public Object getValueAt (TableModel tTABLE_MODEL, int iROW, int iCOLUMN);

  /**
  *  Returns true if the row \a iROW passes the filter.
  *  @param tTABLE_MODEL The table model object.
  *  @param iROW         The row to check.
  *  @return True if the row passes the filter.
  */
  public boolean isAccepted (TableModel tTABLE_MODEL, int iROW);
}
