/*
*  Name:      TMoneyTableCellRenderer.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Table cell renderer for money amounts
*  Date:      $Date: 2004-05-28 19:17:45 +0200 (vie, 28 may 2004) $
*  Revision:  $Revision: 9464 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for TABLE (table support classes).
package org.mpcl.nui.table;

import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import javax.swing.table.DefaultTableCellRenderer;
import org.mpcl.text.TDecimalFormat;
import org.mpcl.util.TMoney;


/**
*  Table cell renderer for \a TMoney objects. It uses a \a DecimalFormat object
*  to convert them to strings. It removes the currency symbol because the units
*  must go in column headers in parentheses (Java Look & Feel Guidelines).
*  @see java.text.DecimalFormat
*/
public class TMoneyTableCellRenderer extends DefaultTableCellRenderer
{

  ///  Number format.
  public DecimalFormat   tDecimalFormat;


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Sets the String object for the cell being rendered to value.
  *  @param tVALUE The value for this cell; if \a tVALUE is \a null it sets the
  *                the text value to an empty string.
  *  @see javax.swing.table.DefaultTableCellRenderer#setValue()
  */
  protected void setValue (Object tVALUE)
  {

    DecimalFormatSymbols   tDecimalFormatSymbols;
    String                 yValue;

    if ( tDecimalFormat == null)
    {
      tDecimalFormat        = (DecimalFormat) TDecimalFormat._getMoneyInstance();
      tDecimalFormatSymbols = tDecimalFormat.getDecimalFormatSymbols();
      tDecimalFormatSymbols.setCurrencySymbol ("");
      tDecimalFormat.setDecimalFormatSymbols (tDecimalFormatSymbols);
    }
    if ( tVALUE == null )
    {
      yValue = "";
    }
    else
    {
      yValue = tDecimalFormat.format (((TMoney) tVALUE).doubleValue()).trim();
    }
    setText (yValue);

  }  // setValue()


  //
  //  C O N S T R U C T O R S
  //

  ///  Builds a new instance.
  public TMoneyTableCellRenderer()
  {
    super();
    setHorizontalAlignment (DefaultTableCellRenderer.RIGHT);
  }

}  // class TMoneyTableCellRenderer
