/*
*  Name:      TPopulationTableCellRenderer.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Table cell renderer for population amounts
*  Date:      $Date: 2004-05-28 02:36:26 +0200 (vie, 28 may 2004) $
*  Revision:  $Revision: 9453 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for TABLE (table support classes).
package org.mpcl.nui.table;

import java.text.NumberFormat;
import javax.swing.table.DefaultTableCellRenderer;
import org.mpcl.text.TDecimalFormat;
import org.mpcl.util.TPopulation;


///  Table cell renderer for \a TPopulation objects.
public class TPopulationTableCellRenderer extends DefaultTableCellRenderer
{

  ///  Number format.
  public NumberFormat   tNumberFormat;


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Sets the String object for the cell being rendered to value.
  *  @param tVALUE The value for this cell; if \a tVALUE is \a null it sets the
  *                the text value to an empty string.
  *  @see javax.swing.table.DefaultTableCellRenderer#setValue()
  */
  protected void setValue (Object tVALUE)
  {
    if ( tNumberFormat == null)
    {
      tNumberFormat = TDecimalFormat._getPopulationInstance();
    }
    setText (( tVALUE == null ) ? "" : tNumberFormat.format (((TPopulation) tVALUE).intValue()));
  }


  //
  //  C O N S T R U C T O R S
  //

  ///  Builds a new instance.
  public TPopulationTableCellRenderer()
  {
    super();
    setHorizontalAlignment (DefaultTableCellRenderer.RIGHT);
  }

}  // class TPopulationTableCellRenderer
