/*
*  Name:      TSelectorTableCellDecorator.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Table cell renderer that makes JTextComponents selected by default
*  Date:      $Date: 2004-02-19 21:57:38 +0100 (jue, 19 feb 2004) $
*  Revision:  $Revision: 8922 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for TABLE (table support classes).
package org.mpcl.nui.table;

import java.awt.Color;
import java.awt.Component;
import javax.swing.JTable;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.text.JTextComponent;


///  Table cell renderer that shows different colors depending on row evenness.
public class TSelectorTableCellDecorator implements ITableCellDecorator
{

  //
  //  S E L E C T O R S
  //

  /**
  *  Returns the component  used for drawing the cell.  If the odd row color is
  *  null then the first time this method is called for an odd row, the odd row
  *  color is taken from the table background color.
  *  @param tCOMPONENT   The component to be colorified.
  *  @param tTABLE       Table where the cell belongs to.
  *  @param tVALUE       Value contained in the cell.
  *  @param gIS_SELECTED True if the cell is selected.
  *  @param gHAS_FOCUS   True if the cell has the focus.
  *  @param iROW         Row of the cell.
  *  @param iCOLUMN      Column of the cell.
  *  @see ITableCellDecorator#getTableCellComponent()
  *  @see javax.swing.table.TableCellRenderer#getTableCellRendererComponent()
  *  @see javax.swing.JTable#getBackground()
  */
  public Component getTableCellComponent ( Component tCOMPONENT   ,
                                           JTable    tTABLE       ,
                                           Object    tVALUE       ,
                                           boolean   gIS_SELECTED ,
                                           boolean   gHAS_FOCUS   ,
                                           int       iROW         ,
                                           int       iCOLUMN      )
  {
    if ( tCOMPONENT instanceof JTextComponent )
    {
      ((JTextComponent) tCOMPONENT).selectAll();
    }
    return tCOMPONENT;
  }

}  // class TSelectorTableCellDecorator
