/*
*  Name:      TStripperTableCellDecorator.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Table cell renderer that displays different colors depending on
*             row evenness
*  Date:      $Date: 2005-03-27 23:17:48 +0200 (dom, 27 mar 2005) $
*  Revision:  $Revision: 10945 $
*
*  Copyright (C) 2003-2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for TABLE (table support classes).
package org.mpcl.nui.table;

import java.awt.Color;
import java.awt.Component;
import javax.swing.JTable;
import javax.swing.table.DefaultTableCellRenderer;


///  Table cell renderer that shows different colors depending on row evenness.
public class TStripperTableCellDecorator implements ITableCellDecorator
{

  ///  Even row background color.
  protected Color   tEvenRowColor;

  ///  Odd row background color.
  protected Color   tOddRowColor;


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Builds a new instance.
  *  @param tEVEN_ROW_COLOR The even row color.
  *  @param tODD_ROW_COLOR  The odd row color.
  */
  public TStripperTableCellDecorator (Color tEVEN_ROW_COLOR, Color tODD_ROW_COLOR)
  {
    super();
    tEvenRowColor = tEVEN_ROW_COLOR;
    tOddRowColor  = tODD_ROW_COLOR;
  }


  //
  //  S E L E C T O R S
  //

  /**
  *  Returns the even for odd rows.
  *  @return The even for odd rows.
  */
  public Color getEvenRowColor()
  {
    return tEvenRowColor;
  }

  /**
  *  Returns the component  used for drawing the cell.  If the odd row color is
  *  null then the first time this method is called for an odd row, the odd row
  *  color is taken from the table background color.
  *  @param tCOMPONENT   The component to be colorified.
  *  @param tTABLE       Table where the cell belongs to.
  *  @param tVALUE       Value contained in the cell.
  *  @param gIS_SELECTED True if the cell is selected.
  *  @param gHAS_FOCUS   True if the cell has the focus.
  *  @param iROW         Row of the cell.
  *  @param iCOLUMN      Column of the cell.
  *  @see ITableCellDecorator#getTableCellComponent()
  *  @see javax.swing.table.TableCellRenderer#getTableCellRendererComponent()
  *  @see javax.swing.JTable#getBackground()
  */
  public Component getTableCellComponent ( Component tCOMPONENT   ,
                                           JTable    tTABLE       ,
                                           Object    tVALUE       ,
                                           boolean   gIS_SELECTED ,
                                           boolean   gHAS_FOCUS   ,
                                           int       iROW         ,
                                           int       iCOLUMN      )
  {

    if ( !gIS_SELECTED )
    {
      if ( (iROW % 2) == 0 )
      {
        tCOMPONENT.setBackground (tEvenRowColor);
      }
      else
      {
        if ( tOddRowColor == null )
        {
          tOddRowColor = tTABLE.getBackground();
        }
        tCOMPONENT.setBackground (tOddRowColor);
      }
    }
    return tCOMPONENT;

  }  // getTableCellComponent()

  /**
  *  Returns the color for odd rows.
  *  @return The color for odd rows.
  */
  public Color getOddRowColor()
  {
    return tOddRowColor;
  }

}  // class TStripperTableCellDecorator
