/*
*  Name:      TTreeTableCellDecorator.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Table tree cell renderer that displays different colors depending
*             on row evenness
*  Date:      $Date: 2004-08-02 19:20:39 +0200 (lun, 02 ago 2004) $
*  Revision:  $Revision: 9838 $
*
*  Copyright (C) 2003-2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for TREETABLE (tree-table support classes).
package org.mpcl.nui.treetable;

import java.awt.Component;
import javax.swing.JTree;
import org.mpcl.nui.table.ITableCellDecorator;


/**
*  Table cell decorator interface  that modifies the appearance of a component.
*  It implements the Decorator design pattern.
*/
public interface ITreeTableCellDecorator extends ITableCellDecorator
{

  //
  //  S E L E C T O R S
  //

  /**
  *  Sets the value of the  current tree cell to \a tVALUE.  If \a gIS_SELECTED
  *  is true, the cell will be drawn as if selected. If \a gIS_EXPANDED is true
  *  the node is currently expanded. If \a gIS_LEAF is true the node represents
  *  a leaf.  If gHAS_FOCUS is true the node  currently has focus.  \a tTREE is
  *  the \a JTree  and  the  receiver  is  being  configured  for.  Returns the
  *  \a Component that the renderer uses to draw the value.
  *  @param tCOMPONENT   Component to be modified.
  *  @param tTREE        Tree where the cell belongs to.
  *  @param tVALUE       Value contained in the cell.
  *  @param gIS_SELECTED True if the cell is selected.
  *  @param gIS_EXPANDED True if the node is expanded.
  *  @param gIS_LEAF     True if the node represents a leaf.
  *  @param iROW         Row of the cell.
  *  @param gHAS_FOCUS   True if the cell has the focus.
  *  @return The \a Component that the renderer uses to draw the value.
  *  @see ITreeTableCellRenderer#getTreeCellRendererComponent()
  */
  public Component getTreeCellRendererComponent ( Component tCOMPONENT   ,
                                                  JTree     tTREE        ,
                                                  Object    tVALUE       ,
                                                  boolean   gIS_SELECTED ,
                                                  boolean   gIS_EXPANDED ,
                                                  boolean   gIS_LEAF     ,
                                                  int       iROW         ,
                                                  boolean   gHAS_FOCUS   );

}  // interface ITreeTableCellDecorator
