/*
*  Name:        TTreeTableCellEditor.java
*  Author:      Philip Milne
*               Scott Violet
*  Maintainer:  Rafael Jesus Alcantara Perez
*  Summary:     Text field class used for editing tree-table cells.
*  Date:        $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:    $Revision: 8535 $
*
*  Copyright (C) 2003  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*
*
*  Copyright 1997-2000 Sun Microsystems, Inc. All Rights Reserved.
*
*  Redistribution and use in source and binary forms, with or
*  without modification, are permitted provided that the following
*  conditions are met:
*
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*
*  - Redistribution in binary form must reproduce the above
*    copyright notice, this list of conditions and the following
*    disclaimer in the documentation and/or other materials
*    provided with the distribution.
*
*  Neither the name of Sun Microsystems, Inc. or the names of
*  contributors may be used to endorse or promote products derived
*  from this software without specific prior written permission.
*
*  This software is provided "AS IS," without a warranty of any
*  kind. ALL EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND
*  WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY,
*  FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE HEREBY
*  EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE LIABLE FOR ANY
*  DAMAGES OR LIABILITIES SUFFERED BY LICENSEE AS A RESULT OF OR
*  RELATING TO USE, MODIFICATION OR DISTRIBUTION OF THIS SOFTWARE OR
*  ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS LICENSORS BE LIABLE
*  FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT,
*  SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
*  CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF
*  THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF SUN HAS
*  BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*
*  You acknowledge that this software is not designed, licensed or
*  intended for use in the design, construction, operation or
*  maintenance of any nuclear facility.
*/

///  Package name for TREETABLE (tree-table support classes).
package org.mpcl.nui.treetable;

import javax.swing.JTextField;


/**
*  Component used by  \a TTreeTableCellEditor.  The only thing  this does is to
*  override  the \a reshape() method,  and to  always  make  the X location  be
*  \a iOffset.
*/
public class TTextField extends JTextField
{

  ///  Offset.
  public int   iOffset;


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Moves and resizes this component.  It is overridden  to set the X location
  *  to \a iOffset.
  *  @param iX      The new horizontal location.
  *  @param iY      The new vertical location.
  *  @param iWIDTH  The new width.
  *  @param iHEIGHT The new height.
  */
  public void reshape (int iX, int iY, int iWIDTH, int iHEIGHT)
  {
    int   iNewX = Math.max (iX, iOffset);

    super.reshape (iNewX, iY, iWIDTH - (iNewX - iX), iHEIGHT);
  }

  /**
  *  Sets the offset.
  *  @param iOFFSET The new offset.
  */
  public void setOffset (int iOFFSET)
  {
    iOffset = iOFFSET;
  }

}  // class TTextField
