/*
*  Name:        TTreeTableAppearanceModelToTableAppearanceModelAdapter.java
*  Author:      Rafael Jesus Alcantara Perez
*  Summary:     Tree-table appearance model to table appearance model adapter.
*  Date:        $Date: 2004-10-11 00:59:30 +0200 (lun, 11 oct 2004) $
*  Revision:    $Revision: 10229 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for TREETABLE (tree-table support classes).
package org.mpcl.nui.treetable;

import java.awt.Dimension;
import javax.swing.JTree;
import javax.swing.SwingUtilities;
import javax.swing.tree.TreePath;
import javax.swing.event.TreeExpansionEvent;
import javax.swing.event.TreeExpansionListener;
import javax.swing.event.TreeModelEvent;
import javax.swing.event.TreeModelListener;
import org.mpcl.nui.table.ITableAppearanceModel;


/**
*  This is  an adapter  class that  takes an  \a ITreeTableAppearanceModel  and
*  implements  the \a ITableAppearanceModel  interface.  The implementation  is
*  trivial,  with  all  of  the  event  dispatching  support  provided  by  the
*  superclass \a AbstractTableModel. 
*/
public class TTreeTableAppearanceModelToTableAppearanceModelAdapter
  implements ITableAppearanceModel
{

  ///  The tree.
  private JTree   tTree;

  ///  The tree-table model.
  private ITreeTableAppearanceModel   tTreeTableAppearanceModel;


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Builds a new instance.
  *  @param tTREE_TABLE_MODEL A tree-table model.
  *  @param tTREE             A tree.
  */
  public TTreeTableAppearanceModelToTableAppearanceModelAdapter
  (
    ITreeTableAppearanceModel tTREE_TABLE_APPEARANCE_MODEL ,
    JTree                     tTREE
  )
  {
    tTree                     = tTREE;
    tTreeTableAppearanceModel = tTREE_TABLE_APPEARANCE_MODEL;
  }


  //
  //  S E L E C T O R S
  //

  /**
  *  Returns the node at row \a iROW.
  *  @return The node.
  */
  protected Object getNodeForRow (int iROW)
  {
    return tTree.getPathForRow (iROW).getLastPathComponent();         
  }


  //
  //  S E L E C T O R S
  //

  /**
  *  Returns the minimum width for a table column.
  *  @param iCOLUMN Column index on the table.
  *  @return The minimum column width for column at index \a iCOLUMN.
  */
  public int getColumnMinWidth (int iCOLUMN)
  {
    return tTreeTableAppearanceModel.getColumnMinWidth (iCOLUMN);
  }

  /**
  *  Returns the preferred scrollable viewport size for the table.
  *  @return The preferred scrollable viewport size.
  *  @see javax.swing.JTable#setPreferredScrollableViewportSize()
  */
  public Dimension getPreferredScrollableViewportSize()
  {
    return tTreeTableAppearanceModel.getPreferredScrollableViewportSize();
  }

  /**
  *  Gets the tool-tip for the cell at row \a iROW and column \a iCOLUMN.
  *  @param iROW    Row index.
  *  @param iCOLUMN Column index.
  *  @return The tool-tip.
  */
  public String getToolTipText (int iROW, int iCOLUMN)
  {
    return tTreeTableAppearanceModel.getToolTipText (getNodeForRow (iROW), iCOLUMN);
  }

}  // class TTreeTableAppearanceModelToTableAppearanceModelAdapter
