/*
*  Name:      TDecimalFormat.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Class that adds support for formatting money, percent and so
*  Date:      $Date: 2004-05-28 02:36:26 +0200 (vie, 28 may 2004) $
*  Revision:  $Revision: 9453 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for text related classes.
package org.mpcl.text;

import java.text.DecimalFormat;
import java.text.NumberFormat;


/**
*  Class  to  convert   from   numbers  to  their  string   representation  and
*  vice-versa.
*/
public abstract class TDecimalFormat extends DecimalFormat
{

  //
  //  C O N S T R U C T O R S
  //

  ///  Builds a new instance. Private because this is really a factory.
  private TDecimalFormat() {}


  //
  //  C O N S T R U C T O R S
  //

  public static NumberFormat _getMoneyInstance()
  {
    return NumberFormat.getCurrencyInstance();
  }

  public static NumberFormat _getPercentInstance()
  {
    int            iMinFractionDigits;
    NumberFormat   tNumberFormat;

    tNumberFormat      = DecimalFormat.getPercentInstance();
    iMinFractionDigits = tNumberFormat.getMinimumFractionDigits();
    iMinFractionDigits = Math.max (iMinFractionDigits, 2);
    tNumberFormat.setMinimumFractionDigits (iMinFractionDigits);
    return tNumberFormat;
  }

  public static NumberFormat _getPopulationInstance()
  {
    return DecimalFormat.getIntegerInstance();
  }

}  // class TDecimalFormat
