/*
*  Name:      TStringUtils.java
*  Author:    Francisco Vides Fernandez
*  Summary:   Miscellaneous functions for formatting strings
*  Date:      $Date: 2004-10-22 01:13:50 +0200 (vie, 22 oct 2004) $
*  Revision:  $Revision: 10319 $
*
*  Copyright (C) 2001-2003  Francisco Vides Fernandez <pax@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for text related classes.
package org.mpcl.text;

import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;


///  Class that performs miscellaneous changes on Strings.
public class TStringUtils
{

  //
  //  S E L E C T O R S
  //

  /**
  *  Translates some unicode characters to basic latin unicode characters. This
  *  a univocal translation because it is a many-to-one relation.
  *  @param ySOURCE The string to be translated.
  *  @return The translated string.
  */
  public static String _normalize (String ySOURCE)
  {

    int            I;
    char           cChar;
    int            iLength       = ySOURCE.length();
    StringBuffer   yStringBuffer = new StringBuffer (iLength);

    for ( I = 0; ( I < iLength ) ;++I)
    {
      cChar = ySOURCE.charAt (I);
      switch (cChar)
      {
        case '\u00a9':
        {
          //
          //  COPYRIGHT SIGN => "(C)"
          //
          yStringBuffer.append ("(C)"); break;
        }
        case '\u00ae':
        {
          //
          //  REGISTERED SIGN => "(R)"
          //
          yStringBuffer.append ("(R)"); break;
        }
        case '\u00c0':
        case '\u00c1':
        case '\u00c2':
        case '\u00c3':
        case '\u00c4':
        case '\u00c5':
        {
          //
          //  LATIN CAPITAL LETTER A WITH GRAVE      => 'A'
          //  LATIN CAPITAL LETTER A WITH ACUTE      => 'A'
          //  LATIN CAPITAL LETTER A WITH CIRCUMFLEX => 'A'
          //  LATIN CAPITAL LETTER A WITH TILDE      => 'A'
          //  LATIN CAPITAL LETTER A WITH DIAERESIS  => 'A'
          //  LATIN CAPITAL LETTER A WITH RING ABOVE => 'A'
          //
          yStringBuffer.append ('A'); break;
        }
        case '\u00c8':
        case '\u00c9':
        case '\u00ca':
        case '\u00cb':
        {
          //
          //  LATIN CAPITAL LETTER E WITH GRAVE      => 'E'
          //  LATIN CAPITAL LETTER E WITH ACUTE      => 'E'
          //  LATIN CAPITAL LETTER E WITH CIRCUMFLEX => 'E'
          //  LATIN CAPITAL LETTER E WITH DIAERESIS  => 'E'
          //
          yStringBuffer.append ('E'); break;
        }
        case '\u00cc':
        case '\u00cd':
        case '\u00ce':
        case '\u00cf':
        {
          //
          //  LATIN CAPITAL LETTER I WITH GRAVE      => 'I'
          //  LATIN CAPITAL LETTER I WITH ACUTE      => 'I'
          //  LATIN CAPITAL LETTER I WITH CIRCUMFLEX => 'I'
          //  LATIN CAPITAL LETTER I WITH DIAERESIS  => 'I'
          //
          yStringBuffer.append ('I'); break;
        }
        case '\u00d2':
        case '\u00d3':
        case '\u00d4':
        case '\u00d5':
        case '\u00d6':
        {
          //
          //  LATIN CAPITAL LETTER O WITH GRAVE      => 'O'
          //  LATIN CAPITAL LETTER O WITH ACUTE      => 'O'
          //  LATIN CAPITAL LETTER O WITH CIRCUMFLEX => 'O'
          //  LATIN CAPITAL LETTER O WITH TILDE      => 'O'
          //  LATIN CAPITAL LETTER O WITH DIAERESIS  => 'O'
          //
          yStringBuffer.append ('O'); break;
        }
        case '\u00d9':
        case '\u00da':
        case '\u00db':
        case '\u00dc':
        {
          //
          //  LATIN CAPITAL LETTER U WITH GRAVE      => 'U'
          //  LATIN CAPITAL LETTER U WITH ACUTE      => 'U'
          //  LATIN CAPITAL LETTER U WITH CIRCUMFLEX => 'U'
          //  LATIN CAPITAL LETTER U WITH DIAERESIS  => 'U'
          //
          yStringBuffer.append ('U'); break;
        }
        case '\u00e0':
        case '\u00e1':
        case '\u00e2':
        case '\u00e3':
        case '\u00e4':
        case '\u00e5':
        {
          //
          //  LATIN SMALL LETTER A WITH GRAVE      => 'a'
          //  LATIN SMALL LETTER A WITH ACUTE      => 'a'
          //  LATIN SMALL LETTER A WITH CIRCUMFLEX => 'a'
          //  LATIN SMALL LETTER A WITH TILDE      => 'a'
          //  LATIN SMALL LETTER A WITH DIAERESIS  => 'a'
          //  LATIN SMALL LETTER A WITH RING ABOVE => 'a'
          //
          yStringBuffer.append ('a'); break;
        }
        case '\u00e8':
        case '\u00e9':
        case '\u00ea':
        case '\u00eb':
        {
          //
          //  LATIN SMALL LETTER E WITH GRAVE      => 'e'
          //  LATIN SMALL LETTER E WITH ACUTE      => 'e'
          //  LATIN SMALL LETTER E WITH CIRCUMFLEX => 'e'
          //  LATIN SMALL LETTER E WITH DIAERESIS  => 'e'
          //
          yStringBuffer.append ('e'); break;
        }
        case '\u00ec':
        case '\u00ed':
        case '\u00ee':
        case '\u00ef':
        {
          //
          //  LATIN SMALL LETTER I WITH GRAVE      => 'i'
          //  LATIN SMALL LETTER I WITH ACUTE      => 'i'
          //  LATIN SMALL LETTER I WITH CIRCUMFLEX => 'i'
          //  LATIN SMALL LETTER I WITH DIAERESIS  => 'i'
          //
          yStringBuffer.append ('i'); break;
        }
        case '\u00f2':
        case '\u00f3':
        case '\u00f4':
        case '\u00f5':
        case '\u00f6':
        {
          //
          //  LATIN SMALL LETTER O WITH GRAVE      => 'o'
          //  LATIN SMALL LETTER O WITH ACUTE      => 'o'
          //  LATIN SMALL LETTER O WITH CIRCUMFLEX => 'o'
          //  LATIN SMALL LETTER O WITH TILDE      => 'o'
          //  LATIN SMALL LETTER O WITH DIAERESIS  => 'o'
          //
          yStringBuffer.append ('o'); break;
        }
        case '\u00f9':
        case '\u00fa':
        case '\u00fb':
        case '\u00fc':
        {
          //
          //  LATIN SMALL LETTER U WITH GRAVE      => 'u'
          //  LATIN SMALL LETTER U WITH ACUTE      => 'u'
          //  LATIN SMALL LETTER U WITH CIRCUMFLEX => 'u'
          //  LATIN SMALL LETTER U WITH DIAERESIS  => 'u'
          //
          yStringBuffer.append ('u'); break;
        }
        case '\u00c6':
        {
          //
          //  LATIN CAPITAL LETTER AE => "AE"
          //
          yStringBuffer.append ("AE"); break;
        }
        case '\u00e6':
        {
          //
          //  LATIN SMALL LETTER AE => "ae"
          //
          yStringBuffer.append ("ae"); break;
        }
        case '\u00c7':
        {
          //
          //  LATIN CAPITAL LETTER C WITH CEDILLA => 'C'
          //
          yStringBuffer.append ('C'); break;
        }
        case '\u00e7':
        {
          //
          //  LATIN SMALL LETTER C WITH CEDILLA => 'c'
          //
          yStringBuffer.append ('c'); break;
        }
        case '\u00d1':
        {
          //
          //  LATIN CAPITAL LETTER N WITH TILDE => 'N'
          //
          yStringBuffer.append ('N'); break;
        }
        case '\u00f1':
        {
          //
          //  LATIN SMALL LETTER N WITH TILDE => 'n'
          //
          yStringBuffer.append ('n'); break;
        }
        default:
        {
          yStringBuffer.append (cChar); break;
        }
      }
    }
    return yStringBuffer.toString();

  }  // _normalize()

  /**
  *  Takes a string  containing space-separated  tokens and returns a list with
  *  them.
  *  @arg yKEYS The string to tokenize.
  *  @return The token list.
  */
  public static List _tokenizeKeys (String yKEYS)
  {

    StringTokenizer   tTokenizer;
    List              tTokenList = new ArrayList();

    try
    {
      tTokenizer = new StringTokenizer (yKEYS);
      while ( tTokenizer.hasMoreTokens() )
      {
        tTokenList.add (tTokenizer.nextToken());
      }
    }
    catch (final NullPointerException ktEXCEPTION)
    {
      //
      //  It does nothing if the string is null.
      //
    }
    return tTokenList;

  }  // _tokenizeKeys()

  /**
  *  If string \a ySOURCE length  is greater than  \a iMAX_LENGTH then it wraps
  *  to the substring 0..I-1 where I is the  index of the last  ocurrence of an
  *  space ' '  within. By default, an ellipsis is appended.
  *  @arg ySOURCE     The string to be wrapped.
  *  @arg iMAX_LENGTH The max length of the resulting string.
  *  @return The wrapped string.
  *  @see #_wrapString (String, int, char)
  */
  public static String _wrapString (String ySOURCE, int iMAX_LENGTH)
  {
    return _wrapString (ySOURCE, iMAX_LENGTH, ' ', "...");
  }

  /**
  *  If string \a ySOURCE  length is  greater than \a iMAX_LENGTH then it wraps
  *  to the substring 0..I-1  where I is the  index of the  last  ocurrence  of
  *  \a cLAST_CHAR within. By default, an ellipsis is appended.
  *  @arg ySOURCE     The string to be wrapped.
  *  @arg iMAX_LENGTH The maximum length of the resulting string.
  *  @arg cLAST_CHAR  The last char of the resulting string.
  *  @return The wrapped string.
  */
  public static String _wrapString (String ySOURCE, int iMAX_LENGTH, char cLAST_CHAR)
  {
    return _wrapString (ySOURCE, iMAX_LENGTH, cLAST_CHAR, "...");
  }

  /**
  *  The same  as \a _wrapString (String, int, char)  but appends a tail if the
  *  string was wrapped.
  *  @arg ySOURCE     The string to be wrapped.
  *  @arg iMAX_LENGTH The maximum length of the resulting string.
  *  @arg cLAST_CHAR  The last char of the resulting string.
  *  @arg ySUFFIX     The string to append.
  *  @return The wrapped string.
  *  @see #_wrapString (String, int, char)
  */
  public static String _wrapString ( String ySOURCE     ,
                                     int    iMAX_LENGTH ,
                                     char   cLAST_CHAR  ,
                                     String ySUFFIX     )
  {

    int      iLastIndex;
    String   yWrapped;
    
    if ( ( ySOURCE == null ) || ( ySOURCE.length() <= iMAX_LENGTH ) )
    {
      yWrapped = ySOURCE;
    }
    else
    {
      yWrapped   = ySOURCE.substring (0, iMAX_LENGTH);
      iLastIndex = yWrapped.lastIndexOf (cLAST_CHAR);
      if ( iLastIndex >= 0 )
      {
        yWrapped = yWrapped.substring (0, iLastIndex);
      }
      yWrapped += ySUFFIX;
    }
    return yWrapped;

  }  // _wrapString()

}  // class TStringUtils
