/*
*  Name:      THtmlAnchor.java
*  Author:    Francisco Vides Fernandez
*  Summary:   Html anchor class
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 2001-2003  Francisco Vides Fernandez <pax@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for HTML related classes.
package org.mpcl.text.html;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;


public class THtmlAnchor
{

  public static final int _kiAbsolute = 1;

  public static final int _kiRelative = 2;

  public static final String  _kyHttpPrefix = "http://";

  ///  If this anchor is absolute or relative.
  protected int  iType;

  ///  The variables we put at the right side of ? which have one unique value.
  protected HashMap tHrefValues;

  /** 
  *  The variables  we put at  the right  side of '?' which have  more than one
  *  value.
  */
  protected HashMap tHrefMultipleValues;

  /// Anchor values
  protected HashMap tValues;

  /// The value at the left of ?
  protected String  yUrl;

  /// Precalculated value of href variables
  protected String  yHrefValues;

  /// The selected text
  protected String  yText;

  /// Precalculated value of anchor variables
  protected String  yValues;


  //
  //  C O N S T R U C T O R S
  //

  public THtmlAnchor()
  {
    iType               = _kiRelative;
    tHrefMultipleValues = null;
    tHrefValues         = new HashMap();
    tValues             = new HashMap();
    yHrefValues         = null;
    yText               = null;;
    yUrl                = null;
    yValues             = null;
  }

  public THtmlAnchor (String yURL)
  {
    iType               = _kiRelative;
    tHrefMultipleValues = null;
    tHrefValues         = new HashMap();
    tValues             = new HashMap();
    yHrefValues         = null;
    yText               = yURL;
    yValues             = null;
    setUrl (yURL);
  }

  public THtmlAnchor (String yURL, int iLINK_TYPE)
  {

    switch (iLINK_TYPE)
    {
      case _kiAbsolute:
      {
        iType = iLINK_TYPE;
        break;
      }
      case _kiRelative:
      {
        iType = iLINK_TYPE;
        break;
      }
      default:
      {
        iType = _kiRelative;
      }
    }
    tHrefMultipleValues = null;
    tHrefValues         = new HashMap();
    tValues             = new HashMap();
    yHrefValues         = null;
    yText               = yURL;
    yValues             = null;
    setUrl (yURL);

  }  // THtmlAnchor()

  /**
  *  Creates a new variable if it did not existed or add a new value if it
  *  previously existed.
  */
  public void addHrefValue (String yKEY, String yVALUE)
  {

    yHrefValues = null;
    if ( !tHrefValues.containsKey (yKEY) )
    {
      if ( ( tHrefMultipleValues == null )            ||
           ( !tHrefMultipleValues.containsKey (yKEY) ) )
      {
        tHrefValues.put (yKEY, yVALUE);
      }
      else
      {
        ((List) tHrefMultipleValues.get (yKEY)).add (yVALUE);
      }
    }
    else
    {
      List   tValues = new ArrayList();

      if ( tHrefMultipleValues == null )
      {
        tHrefMultipleValues = new HashMap();
      }
      tValues.add (tHrefValues.get (yKEY));
      tValues.add (yVALUE);
      tHrefMultipleValues.put (yKEY, tValues);
      tHrefValues.remove (yKEY);
    }

  }  // addHrefValue()

  public void setContent (String yTEXT)
  {
    yText = ( yTEXT != null ) ? yTEXT : "";
  }

  /**
  *  Set the value of given parameter, deleting previous values if existed.
  */
  public void setHrefValue (String yKEY, String yVALUE)
  {

    yHrefValues = null;
    if ( ( tHrefMultipleValues != null )           &&
         ( tHrefMultipleValues.containsKey (yKEY) ) )
    {
      tHrefMultipleValues.remove (yKEY);
      if ( tHrefMultipleValues.size() == 0 )
      {
        tHrefMultipleValues = null;
      }
    }
    tHrefValues.put (yKEY, yVALUE);
      
  } // setHrefValue()

  public void setUrl (String yURL)
  {

    if ( yURL == null )
    {
      throw new NullPointerException();
    }
    else
    {
      if ( ( iType == _kiAbsolute )                                                &&
           ( !_kyHttpPrefix.equals (yURL.substring (0, _kyHttpPrefix.length())) ) )
      {
        // if there is no http prefix, we preppend it
        yUrl = _kyHttpPrefix + yURL;
      }
      else
      {
        yUrl = yURL;
      }
    }

  }  // setUrl()

  public void setValue (String yKEY, String yVALUE)
  {
    yValues = null;
    tValues.put (yKEY, yVALUE);
  }


  //
  //  S E L E C T O R S
  //
  
  protected String getHrefValues()
  {

    String    yKEY;
    boolean   gFirst = true;
    String    yRet   = "";
    String    ySeparator = "?";
    
    if ( yHrefValues == null )
    {
      Iterator   I = tHrefValues.keySet().iterator();
      yHrefValues = "";
      while ( I.hasNext() )
      {
        yKEY = (String) I.next();
        yHrefValues += ySeparator + yKEY + "=" + (String) tHrefValues.get (yKEY);
        if ( gFirst )
        {
          ySeparator = "&";
          gFirst = false;
        }
      }
      if ( tHrefMultipleValues != null )
      {
        Iterator    J;
        String      yValue;
        I = tHrefMultipleValues.keySet().iterator();
        while ( I.hasNext() )
        {
          yKEY = (String) I.next();
          J    = ((List) tHrefMultipleValues.get (yKEY)).iterator();
          while ( J.hasNext() )
          {
            yValue = (String) J.next();
            yHrefValues += ySeparator + yKEY + "=" + yValue;
            if ( gFirst )
            {
              ySeparator = "&";
              gFirst     = false;
            }
          }
        }
      }
    }
    yRet = yHrefValues;
    return yRet;

  }  // getSimpleHrefValues()

  protected String getValues()
  {

    String    yKey;
    boolean   gFirst     = true;
    String    yRet       = "";
    String    ySeparator = "";
    
    if ( yValues == null )
    {
      Iterator   I = tValues.keySet().iterator();

      yValues = "";
      while ( I.hasNext() )
      {
        yKey = (String) I.next();
        yValues += ySeparator + yKey + "=\"" + (String) tValues.get (yKey) + "\"";
        if ( gFirst )
        {
          ySeparator = " ";
          gFirst = false;
        }
      }
    }
    yRet = yValues;
    return yRet;

  }  // getValues()

  public static String getMailTo (String yMAIL_ADDRESS)
  {
    return "<a href=\"mailto:" + yMAIL_ADDRESS + "\">" + yMAIL_ADDRESS + "</a>";
  }

  public String getValue (String yKEY)
  {
    return (String) tValues.get (yKEY);
  }

  public String toHtml()
  {
    String   yRet = "<a ";
    
    if ( yUrl != null )
    {
      yRet += "href=\"" + yUrl + getHrefValues() + "\" ";
    }
    yRet += getValues() + ">" + yText + "</a>";
    return yRet;
  }

}  // class THtmlAnchor
