/*
*  Name:      THtmlDate.java
*  Author:    Francisco Vides Fernandez
*  Summary:   Class for rendering HTML date fields
*  Date:      $Date: 2003-11-27 12:04:28 +0100 (jue, 27 nov 2003) $
*  Revision:  $Revision: 8535 $
*
*  Copyright (C) 2001  Francisco Vides Fernandez <pax@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for HTML related classes.
package org.mpcl.text.html;

import java.text.DateFormatSymbols;
import java.util.GregorianCalendar;
import java.util.Locale;


public class THtmlDate
{

  protected boolean gEnableMultiple;

  protected int iDay;

  protected int iMonth;

  protected int iYear;
  
  protected GregorianCalendar tCalendar;
  
  protected Locale tLocale;

  protected String yNamePrefix;


  //
  //  C O N S T R U C T O R S
  //

  protected void setCalendar()
  {
    if ( ( iDay > 0 ) && ( iMonth > 0 ) && (iYear > 0) )
    {
      tCalendar.set (iYear, iMonth, iDay);
    }
  }


  //
  //  C O N S T R U C T O R S
  //

  public THtmlDate (String yDAY, String yMONTH, String yYEAR, String yNAME_PREFIX)
  {
    tLocale = Locale.getDefault();
    tCalendar = new GregorianCalendar (tLocale);
    setDay (yDAY);
    setMonth (yMONTH);
    setYear (yYEAR);
    setNamePrefix (yNAME_PREFIX);
    setCalendar();
  }

  public void setDay (String yDAY)
  {

    try
    {
      iDay = Integer.parseInt (yDAY);
      if ( iDay < 0 )
      {
        iDay = 0;
      }
      if ( iDay > 31 )
      {
        iDay = 0;
      }
    }
    catch (NumberFormatException tEXCEPTION)
    {
      iDay = -1;
    }

  }  // setDay()

  public void setEnableMultple (boolean gENABLE)
  {
    gEnableMultiple = gENABLE;
  }

  public void setMonth (String yMONTH)
  {

    try
    {
      iMonth = Integer.parseInt (yMONTH);
      if ( iMonth < 0 )
      {
        iMonth = 0;
      }
      if ( iMonth > 11 )
      {
        iMonth = 0;
      }
    }
    catch (NumberFormatException tEXCEPTION)
    {
      iMonth = -1;
    }

  }  // setMonth()

  public void setYear (String yYEAR)
  {
    try
    {
      iYear = Integer.parseInt (yYEAR);
    }
    catch (NumberFormatException tEXCEPTION)
    {
      iYear = -1;
    }
  }

  public void setLocale (Locale tLOCALE)
  {
    if ( tLOCALE != null )
    {
      tLocale = tLOCALE;
      tCalendar = new GregorianCalendar (tLocale);
    }
    else
    {
      throw new NullPointerException();
    }
  }

  public void setNamePrefix (String yNAME_PREFIX)
  {
    yNamePrefix = ( yNAME_PREFIX != null ) ? yNAME_PREFIX : "";
  }


  //
  //  S E L E C T O R S
  //  

  protected StringBuffer getDays()
  {

    StringBuffer  yRet = new StringBuffer()
      .append ("<select name='").append (yNamePrefix).append ("Day'>\n")
      .append ("<option value=''>--</option>\n");
    for (int I = 1; I <= tCalendar.getMaximum (GregorianCalendar.DAY_OF_MONTH) ; I++)
    {
      yRet = yRet.append ("<option value='").append (I).append ("'");
      if ( I == iDay )
      {
        yRet = yRet.append (" selected");
      }
      yRet = yRet.append (">").append (I).append ("</option>\n");
    }
    yRet = yRet.append ("</select>");
    return yRet;

  }  // getDays()

  protected StringBuffer getMonths()
  {

    StringBuffer  yRet = new StringBuffer()
      .append ("<select name='").append (yNamePrefix).append ("Month'>\n")
      .append ("<option value=''>------</option>\n");
    String  ayMonths[] = (new DateFormatSymbols (tLocale)).getMonths();

    for (int I = 0; I < 12 ; I++)
    {
      yRet = yRet.append ("<option value='").append (I).append ("'");
      if ( I == iMonth )
      {
        yRet = yRet.append (" selected");
      }
      yRet = yRet.append (">").append (ayMonths [I]).append ("</option>\n");
    }
    yRet = yRet.append ("</select>");
    return yRet;

  }  // getMonths()

  protected StringBuffer getYears()
  {

    int       iYearCurrent;
    int       iYearFrom;
    int       iYearUntil;
    StringBuffer    yRet = new StringBuffer()
      .append ("<select name='").append (yNamePrefix).append ("Year'>\n")
      .append ("<option value=''>----</option>\n");


    iYearCurrent = ( iYear > 0 ) ? iYear : tCalendar.get (GregorianCalendar.YEAR);
    iYearFrom = iYearCurrent - 10;
    iYearUntil = iYearCurrent + 10;

    for (int I = iYearFrom; I <= iYearUntil ; I++)
    {
      yRet = yRet.append ("<option value='").append (I).append ("'");
      if ( I == iYear )
      {
        yRet = yRet.append (" selected");
      }
      yRet = yRet.append (">").append (I).append ("</option>\n");
    }
    yRet = yRet.append ("</select>");
    return yRet;

  }  // getYears()

  public StringBuffer toHtml()
  {
    StringBuffer yRet;

    yRet = new StringBuffer()
      .append ("<td>\n").append (getDays()).append ("</td>\n<td>\n")
      .append (getMonths()).append ("\n</td>\n<td>\n")
      .append (getYears()).append ("\n</td>");
    return yRet;
  }

}  // class THtmlDate
