/*
*  Name:      TDuration.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Simple class for time duration
*  Date:      $Date: 2004-11-13 03:36:10 +0100 (sáb, 13 nov 2004) $
*  Revision:  $Revision: 10441 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for UTIL.
package org.mpcl.util;

import org.mpcl.text.TDurationFormat;


///  Simple class for time duration.
public class TDuration extends Number
{

  ///  Duration format.
  private static TDurationFormat   _tDurationFormat = TDurationFormat._getDurationInstance();

  ///  Duration in milliseconds.
  private long   lMilliseconds;


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Constructs  a  newly  allocated \a TDuration  object  that  represents the
  *  primitive double argument.
  *  @param lMILLISECONDS The duration in milliseconds.
  */
  public TDuration (long lMILLISECONDS)
  {
    super();
    lMilliseconds = lMILLISECONDS;
  }

  /**
  *  Builds a new instance. It represents the floating-point value of type
  *  double represented by the string. The string is converted to a double
  *  value as if by the \a valueOf method.
  *  @param yVALUE A string to be converted to a \a Double.
  *  @throws NumberFormatException
  *          If the string does not contain a parseable number.
  */
  public TDuration (String yVALUE) throws NumberFormatException
  {
    super();
    lMilliseconds = Long.parseLong (yVALUE);
  }


  //
  //  S E L E C T O R S
  //

  /**
  *  Returns a string representation of the time duration argument.
  *  @param lMILLISECONDS The duration in milliseconds.
  *  @return The string representation of the time duration argument.
  */
  public static String _toString (long lMILLISECONDS)
  {
    return new TDuration (lMILLISECONDS).toString();
  }

  /**
  *  Returns the value of the specified number as a double.
  */
  public double doubleValue()
  {
    return (double) lMilliseconds;
  }

  /**
  *  Returns the value of the specified number as a float.
  */
  public float floatValue()
  {
    return (float) lMilliseconds;
  }

  /**
  *  Returns the value of the specified number as an int.
  */
  public int intValue() 
  {
    return (int) lMilliseconds;
  }

  /**
  *  Returns the value of the specified number as a long.
  */
  public long longValue() 
  {
    return lMilliseconds;
  }

  /**
  *  Returns a string representation of this object.
  *  @return The string representation of this object.
  */
  public String toString()
  {
    return _tDurationFormat.format (new Long (lMilliseconds));
  }

}  // class TDuration
