/*
*  Name:      TPopulation.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Simple class for population amounts
*  Date:      $Date: 2005-01-19 16:57:59 +0100 (mié, 19 ene 2005) $
*  Revision:  $Revision: 10621 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for UTIL.
package org.mpcl.util;


///  Simple class for population amounts.
public class TPopulation extends Number
{

  ///  Value.
  private int   iValue;

  ///  A constant holding the largest positive finite value of type int.
  public static final int   MAX_VALUE = Integer.MAX_VALUE;

  ///  A constant holding the smallest positive nonzero value of type int.
  public static final int   MIN_VALUE = Integer.MIN_VALUE;


  //
  //  C O N S T R U C T O R S
  //

  /**
  *  Builds a new instance. It is a population amount number (using an integer
  *  value).
  *  @param iVALUE The value to be represented.
  */
  public TPopulation (int iVALUE)
  {
    super();
    iValue = iVALUE;
  }

  /**
  *  Builds a new instance. It is a population amount number (using an integer
  *  value).
  *  @param dVALUE The value to be represented by the \a Double.
  */
  public TPopulation (double dVALUE)
  {
    super();
    iValue = (int) dVALUE;
  }

  /**
  *  Builds a new instance. It represents the floating-point value of type
  *  double represented by the string. The string is converted to a double
  *  value as if by the \a valueOf method.
  *  @param yVALUE A string to be converted to a \a Double.
  *  @throws NumberFormatException
  *          If the string does not contain a parseable number.
  */
  public TPopulation (String yVALUE) throws NumberFormatException
  {
    super();
    iValue = Integer.parseInt (yVALUE);
  }


  //
  //  S E L E C T O R S
  //

  /**
  *  Returns the value of the specified number as a double.
  */
  public double doubleValue()
  {
    return iValue;
  }

  /**
  *  Returns the value of the specified number as a float.
  */
  public float floatValue()
  {
    return (float) iValue;
  }

  /**
  *  Returns the value of the specified number as an int.
  */
  public int intValue() 
  {
    return (int) iValue;
  }

  /**
  *  Returns the value of the specified number as a long.
  */
  public long longValue() 
  {
    return (long) iValue;
  }

  /**
  *  Returns a new \a Integer with this population value.
  *  @return The new \a Integer.
  */
  public Double toInteger()
  {
    return new Double (iValue);
  }

  /**
  *  Returns a string representation of this object.
  *  @return The string representation of this object.
  */
  public String toString()
  {
    return String.valueOf (iValue);
  }

}  // class TPopulation
