/*
*  Name:      TTimeClock.java
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Time-clock class
*  Date:      $Date: 2004-11-10 02:00:56 +0100 (mié, 10 nov 2004) $
*  Revision:  $Revision: 10416 $
*
*  Copyright (C) 2004  Rafael Jesus Alcantara Perez <rafa@dedaloingenieros.com>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

///  Package name for UTIL.
package org.mpcl.util;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;


///  Time-clock class. It keeps track of the logged objects.
public class TTimeClock
{

  ///  Map with object to clock-in date bindings.
  private Map   tObjectToDateMap;


  //
  //  C O N S T R U C T O R S
  //

  ///  Builds a new instance.
  public TTimeClock()
  {
    tObjectToDateMap = new HashMap();
  }

  /**
  *  Clocks in the object \a tOBJECT.
  *  @param tOBJECT The object to be clocked in.
  */
  public void clockIn (Object tOBJECT)
  {
    tObjectToDateMap.put (tOBJECT, new Date());
  }

  /**
  *  Clocks out the object \a tOBJECT.
  *  @param tOBJECT The object to be clocked in.
  *  @return The time in miliseconds spent by the object from clock in date.
  */
  public long clockOut (Object tOBJECT)
  {
    Date   tClockInDate;
    Date   tClockOutDate;

    tClockInDate = (Date) tObjectToDateMap.get (tOBJECT);
    tObjectToDateMap.remove (tOBJECT);
    tClockOutDate = new Date();
    return tClockOutDate.getTime() - tClockInDate.getTime();
  }

}  // class TTimeClock
